
JAGS models:
------------

All the JAGS models are adapted from Kruschke (2014). They are in the `code` folder:

- `Jags-Ymet-Xnom-SplitPlot-1Btw-1Wtn-Mrobust.R`: general linear model with one between-subject and one within-subject factor (Sec. 20.5.2 of Kruschke, pag. 610)
- `Jags-Ymet-Xnom-1Fac-Wtn-Mrobust.R`: general linear model with one within-subject factor (Sec. 20.5.2 of Kruschke, pag. 610)
- `Jags-Ymet-Xmet-Mrobust-Subj.R`: individuals within group regression model ("panel regression", Sec 17.3 of Kruschke, pag. 504) with one independent variable
- `Jags-Ymet-XmetThree-Mrobust-Subj.R`: individuals within group regression model ("panel regression", Sec 17.3 of Kruschke, pag. 504) with three independent variables


Datasets:
---------

Datasets are divided into primary and derived. Primary ("raw") datasets are in the `datasets` folde. Derived datasets are datasets derived from the primary datasets by scripts contained in this repository (paths to analysis scripts in this section are relative to the `code` folder). Derived datasets are in the `derived_datasets` folder. All CSV files in the `datasets` and `derived_datasets` folders use space as field separator.

Data dictionaries for the datasets with a short description of each variable are provided in the `data_dictionaries` folder. There is one data dictionary file for each dataset file, the data dictionary filename consists of the dataset filename plus the suffix `_data_dictionary`. CSV files in the data dictionary folder use space as field separator.

Primary datasets include:

- `blinded_ratings.csv`: ratings given by guitar players to each guitar on 16 attributes under blinded conditions
- `unblinded_ratings.csv`: ratings given by guitar players to each guitar on 16 attributes under unblinded conditions
- `visual_ratings.csv`: ratings given by guitar players to each guitar on the visual appearance attributes
- `ABX.csv`: trial by trial results on the ABX task
- `ABX_synth.csv`: trial by trial results on the ABX task with virtual guitars
- `guitarists.csv`: demographics for the guitar players who took part in the tests


Derived datasets include:

- `blinded_ratings_with_EFA_scores.csv`: same as `blinded_ratings.cvs`, but with additional columns listing the factor scores. Generated by the `factor_analysis/factor_analysis.R` script.
- `blinded_ratings_rep1_rep2.csv`: blinded ratings with factor scores and z scores only for players that completed both rating sessions, in a 'wide' format (ratings for the first and second session are listed in different columns). Generated by `compute_z_scores.R`.
- `blinded_ratings_with_EFA_and_z_scores.csv`: ratings with factor scores and z scores for all players. Generated by `compute_z_scores.R`.
- `unblinded_ratings_with_EFA_scores.csv`: same as `unblinded_ratings.cvs`, but with additional columns listing the factor scores. Generated by the `factor_analysis.R` script.
- `ABX_dprime.csv`: d' values in the ABX task calculated from the trial by trial results in `ABX.csv'. Generated by `compute_dprime_ABX.R`
- `ABX_synth_dprime.csv`: d' values in the ABX task with virtual guitars calculated from the trial by trial results in `ABX_synth.csv`. Generated by `compute_dprime_ABX_synth.R`
- `ABX_synth_dprime_CIs.csv`: same as `ABX_synth_dprime.csv` but with bootstrap confidence intervals computed by `ABX_synth_CIs/comp_CIs.jl`


Analysis scripts:
-------------------

The JAGS models are run from R scripts. The scripts are within the following folders:

- `blinded_overall`: analysis of overall sound quality ratings in the blided ratings test
- `blinded_playability`: analysis of playability ratings in the blinded ratings test
- `blinded_correlation_rep1_rep2`: test re-test correlations of blinded overall sound quality, playability ratings, and blinded factor scores
- `blinded_factor_scores`: analysis of factor scores projected onto the blinded ratings
- `blinded_factor_scores_regression`: multiple regression of blinded overall sound quality ratings by factor scores
- `unblinded_overall`: analysis of overall sound quality ratings in the unblided ratings test
- `unblinded_playability`: analysis of playability ratings in the unblinded ratings test
- `unblinded_factor_scores`: analysis of factor scores projected onto the unblinded ratings
- `visual_overall`: analysis of overall visual appearance ratings 
- `ABX`: analysis of performance in the playing ABX test
- `ABX_synth`: analysis of performance in the ABX test with synthesized guitar sounds

Other folders with analysis scripts include:

- `factor_analysis`: factor analysis of blinded ratings
- `ABX_synth_CIs`: Julia functions to compute bootstrap confidence intervals for individual listeners in the ABX test with synthesized guitar sounds


Wood properties data:
---------------------

The file `wood_data.csv` contains the wood properties data (Density and *D_j* values). The script `wood_properties/wood_properties.R` in the `code` folder generates a plot of these data.


Bridge admittance data and code:
--------------------------------

The bridge admittance data are saved in `bridge_admittance_all.mat` in the `datasets` folder as a MAT binary file. Three sets of data are saved in this file, one for the set of six experimental guitars ("Set"), one for the Yamaha guitar ("Yamaha"), and one for the bridge admittances used for the synthesis-based ABX listening tests ("ABX"; this contains data for both the six experimental guitars and the Yamaha guitar).

For each of the data sets above the MAT file contains one variable that stores the complex valued bridge-admittance functions as a matrix (where each column stores the data of a given guitar), and one variable that stores the frequency array for the bridge admittance functions (this is not the same across all data sets). In details the variables contain:

- `specSet`: 6-column matrix with bridge admittance functions for the six experimental guitars. Columns 1 to 6 respectively are for "Braz. Rsw.", "Indian Rsw.", "Mahogany", "Maple", "Sapele", "Walnut"
- `freqArrSet`: frequency array for the six experimental guitars

- `specYamaha`: 1-column matrix with bridge admittance function for the Yamaha guitar
- `freqArrYamaha`: frequency array for the Yamaha guitar

- `specABX`: 7-column matrix with bridge admittance functions used in the ABX test. Columns 1 to 7 respectively are for "Braz. Rsw.", "Indian Rsw.", "Mahogany", "Maple", "Sapele", "Walnut", "Yamaha"
- `freqABX`: frequency array for the ABX bridge admittance functions

See file in the `code/bridge_admittance` folder for plotting the data in R.

Example for plotting in MATLAB:

    load bridge_admittance_all
    % set min and max frequencies
    minPlotFreq = 80; maxPlotFreq = 5000;
    % get indices corresponding to min and max frequencies
    minPlotIdx =  find(abs(freqArrSet-minPlotFreq) == min(abs(freqArrSet-minPlotFreq)))
    maxPlotIdx =  find(abs(freqArrSet-maxPlotFreq) == min(abs(freqArrSet-maxPlotFreq)))
    % plot data for "Braz. Rsw" 
    plot(freqArrSet(minPlotIdx:maxPlotIdx), 20*log10(abs(specSet(minPlotIdx:maxPlotIdx, 1))))
    % plot data for "Mahogany"
    hold on
    plot(freqArrSet(minPlotIdx:maxPlotIdx), 20*log10(abs(specSet(minPlotIdx:maxPlotIdx, 3))))

WAV files used in the ABX test with synthesized guitar sounds:
--------------------------------------------------------------

The `synthesized_guitar_WAV_files` folder contains the WAV files used in the ABX test with synthesized guitar sounds (Experiment 3 of the paper).

Linguistic corpus data:
-----------------------

The files within the `datasets/linguistic_corpus` folder list collocates of the words `sound`, `tone`, `appearance`, `look`, and `looks` retrieved from the corpus analysis of guitar reviews described in the supplementary materials of the paper. Function words have been removed from the lists. A single data dictionary is provided for all these datasets in `data_dictionaries/linguistic_corpus_data_dictionary.csv`.


References
----------

- Kruschke, J. K. (2014). *Doing Bayesian Data Analysis: A Tutorial with R, JAGS, and Stan*. (2nd ed.). London: Academid Press / Elsevier. 
