t1 = Sys.time()
source("../DBDA2E-utilities_SC.R") #postprocessing utilities based on code of Kruschke
source("../DBDA2E-utilities_DF.R") #postprocessing utilities based on code of Kruschke
source("../Jags-Ymet-Xnom-SplitPlot-1Btw-1Wtn-Mrobust.R") #jags model based on code of Kruschke
currDir = getwd()
setwd("../")
source("global_parameters.R")
setwd(currDir)
source("../utils.R")
#load libraries for multi-core parallel processing
library(foreach)
library(doParallel)
library(RColorBrewer)
registerDoParallel(cores=8)


##
updateMCMCSampling = TRUE ## whether to run MCMC or use previously stored results


##directory where to save the results
resDir = "../../results/ABX/"
dir.create(resDir, recursive=T, showWarnings=F)
dir.create(paste0(resDir, "MCMC_diagnostics"), recursive=T, showWarnings=F)
dir.create(paste0(resDir, "figures_data"), recursive=T, showWarnings=F)

## set parameters for MCMC sampling
numSavedStepsAov = 75000
thinStepsAov = 10

datABX = read.table("../../derived_datasets/ABX_dprime.csv", header=T)

#########################################################
#Bayesian ANOVA for d'
#########################################################

if (updateMCMCSampling == TRUE | file.exists(paste0(resDir, "MCMC.RDS")) == FALSE){
    mcmcCoda = genMCMCAov1Btw1WtnRobust(datABX, yName="dprime", xBetweenName="type", xWithinName="cnd", xSubjectName="subject", numSavedSteps=numSavedStepsAov, thinSteps=thinStepsAov) 
    saveRDS(mcmcCoda, file=paste0(resDir, "MCMC.RDS"), compress="xz")
} else {
    mcmcCoda = readRDS(paste0(resDir, "MCMC.RDS"))
}

mcmcMat = as.matrix(mcmcCoda, chains=T)

parameterNames = varnames(mcmcCoda) # get all parameter names
parToPlot = c("b0", "bB[1]", "bB[2]", "bB[3]", "bW[1]", "bW[2]", "bW[3]",
    "bBxW[1,1]", "bBxW[2,1]", "bBxW[3,1]", "bBxW[1,2]", "bBxW[1,3]", "bBxW[2,2]", "bBxW[2,3]", "bBxW[3,3]",
    "bS[1]", "bS[10]", "bS[22]", "bS[7]", "nu", "sigma", "sigmaB", "sigmaW", "sigmaS", "sigmaBxW")

foreach (p=1:length(parToPlot)) %dopar% {
    parName = parToPlot[p]
    pdf(file=paste0(resDir, "MCMC_diagnostics/", parName, ".pdf"), width=7, height=5)
    diagMCMC(codaObject=mcmcCoda, parName=parName)
    dev.off()
}


for (i in 1:length(playerTypes)){
    pdf(paste0(resDir, "post-pred-", playerTypes[i], ".pdf"), width=10)
    plotPostPredAov1Btw1WtnRobust(mcmcCoda, 
                                  datABX, yName="dprime",
                                  xBetweenName="type", xWithinName="cnd",
                                  xSubjectName="subject",
                                  xBetweenLevel=playerTypes[i])
    dev.off()
}

pdf(paste0(resDir, "posterior_nu.pdf"))
plotPost(mcmcMat[,"nu"], ROPE=c(25, 35), compVal=30)
dev.off()

pdf(paste0(resDir, "FullByType.pdf"))
par(mfrow=c(2,2))
plotPost(mcmcMat[,'b0']+mcmcMat[,'bB[1]'], main='professional', cenTend="mode", compVal=0, ROPE=c(-0.2, 0.2))
plotPost(mcmcMat[,'b0']+mcmcMat[,'bB[2]'], main='semi-pro', cenTend="mode", compVal=0, ROPE=c(-0.2, 0.2))
plotPost(mcmcMat[,'b0']+mcmcMat[,'bB[3]'], main='amateur', cenTend="mode", compVal=0, ROPE=c(-0.2, 0.2))
dev.off()

pdf(paste0(resDir, "FullByCnd.pdf"))
par(mfrow=c(2,2))
plotPost(mcmcMat[,'b0']+mcmcMat[,'bW[1]'], main='Rosewood-Sapele', cenTend="mode", compVal=0, ROPE=c(-0.2, 0.2))
plotPost(mcmcMat[,'b0']+mcmcMat[,'bW[2]'], main='Rosewood-Walnut', cenTend="mode", compVal=0, ROPE=c(-0.2, 0.2))
plotPost(mcmcMat[,'b0']+mcmcMat[,'bW[3]'], main='Walnut-Sapele', cenTend="mode", compVal=0, ROPE=c(-0.2, 0.2))
dev.off()

pdf(paste0(resDir, "posterior_b0.pdf"))
plotPost(mcmcMat[,'b0'], main="Average d'", cenTend="mode", compVal=0, ROPE=c(-0.2, 0.2))
dev.off()

xBetweenContrasts = list(
    list(c("professional"), c("amateur"), compVal=0.0, ROPE=c(-0.2,0.2)),
    list(c("professional"), c("semi-pro"), compVal=0.0, ROPE=c(-0.2,0.2)),
    list(c("semi-pro"), c("amateur"), compVal=0.0, ROPE=c(-0.2,0.2))
)
xWithinContrasts = list(
    list(c("Rosewood-Walnut"), c("Rosewood-Sapele"), compVal=0.0, ROPE=c(-0.2,0.2)),
    list(c("Rosewood-Walnut"), c("Walnut-Sapele"), compVal=0.0, ROPE=c(-0.2,0.2)),
    list(c("Rosewood-Sapele"), c("Walnut-Sapele"), compVal=0.0, ROPE=c(-0.2,0.2))
)

xBetweenWithinContrasts = list(
    list(list(c("professional"), c("amateur")),
         list(c("Rosewood-Walnut"), c("Rosewood-Sapele")),
         compVal=0.0, ROPE=c(-0.2,0.2)),
    list(list(c("professional"), c("semi-pro")),
         list(c("Rosewood-Walnut"), c("Rosewood-Sapele")),
         compVal=0.0, ROPE=c(-0.2,0.2)),
    list(list(c("semi-pro"), c("amateur")),
         list(c("Rosewood-Walnut"), c("Rosewood-Sapele")),
         compVal=0.0, ROPE=c(-0.2,0.2)),

    list(list(c("professional"), c("amateur")),
         list(c("Rosewood-Walnut"), c("Walnut-Sapele")),
         compVal=0.0, ROPE=c(-0.2,0.2)),
    list(list(c("professional"), c("semi-pro")),
         list(c("Rosewood-Walnut"), c("Walnut-Sapele")),
         compVal=0.0, ROPE=c(-0.2,0.2)),
    list(list(c("semi-pro"), c("amateur")),
         list(c("Rosewood-Walnut"), c("Walnut-Sapele")),
         compVal=0.0, ROPE=c(-0.2,0.2)),

    list(list(c("professional"), c("amateur")),
         list(c("Rosewood-Sapele"), c("Walnut-Sapele")),
         compVal=0.0, ROPE=c(-0.2,0.2)),
    list(list(c("professional"), c("semi-pro")),
         list(c("Rosewood-Sapele"), c("Walnut-Sapele")),
         compVal=0.0, ROPE=c(-0.2,0.2)),
    list(list(c("semi-pro"), c("amateur")),
         list(c("Rosewood-Sapele"), c("Walnut-Sapele")),
         compVal=0.0, ROPE=c(-0.2,0.2))
)


cntrs_dp = getContrastsAov1Btw1WtnRobust(mcmcCoda, 
    datABX, yName="dprime",
    xBetweenName="type", xWithinName="cnd", xSubjectName="subject",
    xBetweenContrasts=xBetweenContrasts, 
    xWithinContrasts=xWithinContrasts, 
    xBetweenWithinContrasts=xBetweenWithinContrasts)


betweenContrastsDF = data.frame()
for (i in 1:length(pTypePairs)){
    g1 = pTypePairs[[i]][1]; g2 = pTypePairs[[i]][2]
    thisLabelNice = paste0(gsub2(playerTypes, playerLabelsShort, g1), "-", gsub2(playerTypes, playerLabelsShort, g2))
    thisDF = summarizePostDF(cntrs_dp[["between"]][[paste0(g1, "-vs-", g2)]], label=paste0(g1, "-vs-", g2))
    thisDF$labelNice = thisLabelNice
    betweenContrastsDF = rbind(betweenContrastsDF, thisDF)
}
betweenContrastsDF$labelNice = factor(betweenContrastsDF$labelNice, levels=c("Pro-Semipro", "Pro-Amateur", "Semipro-Amateur"), labels=c("Professional - Semi-pro", "Professional - Amateur", "Semi-pro - Amateur"))

p = ggplot(betweenContrastsDF, aes(x=labelNice, y=Mode)) + geom_point(shape=1)
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0)
p = p + geom_hline(yintercept=0, linetype=3) + coord_flip()
#p = p + scale_y_continuous(limits=c(-1,1))
p = p + theme_bw2
p = p + ylab("d' Difference") + theme(axis.title.x = element_text(hjust=1)) + xlab(NULL)
ggsave(filename=paste0(resDir, "HDIs_contrasts_between.pdf"), width=3.4252, height=1.5)
write.table(betweenContrastsDF, paste0(resDir, "figures_data/df_between_contrasts.csv"), row.names=F, col.names=T)



cndPairs = list(c("Rosewood-Walnut", "Rosewood-Sapele"), c("Rosewood-Sapele", "Walnut-Sapele"), c("Rosewood-Walnut", "Walnut-Sapele"))

withinContrastsDF = data.frame()
for (i in 1:length(cndPairs)){
    g1 = cndPairs[[i]][1]; g2 = cndPairs[[i]][2]
    thisDF = summarizePostDF(cntrs_dp[["within"]][[paste0(g1, "-vs-", g2)]], label=paste0(g1, "-vs-", g2))
    withinContrastsDF = rbind(withinContrastsDF, thisDF)
}



p = ggplot(withinContrastsDF, aes(x=label, y=Mode)) + geom_point(shape=1)
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0)
p = p + geom_hline(yintercept=0, linetype=3) + coord_flip()
p = p + theme_bw2 + theme(axis.title.x = element_text(hjust=1)) 
p = p + ylab("d' Difference") + theme(axis.title.x = element_text(hjust=1)) + xlab(NULL)
ggsave(filename=paste0(resDir, "HDIs_contrasts_within.pdf"), width=3.4252, height=3.4252)
write.table(withinContrastsDF, paste0(resDir, "figures_data/df_within_contrasts.csv"), row.names=F, col.names=T)

summDF = summarizePostListDF(list(mcmcMat[,'b0'],
    mcmcMat[,'b0']+mcmcMat[,'bW[1]'],
    mcmcMat[,'b0']+mcmcMat[,'bW[2]'],
    mcmcMat[,'b0']+mcmcMat[,'bW[3]']),
    labels=c("Average", "Rosewood-Sapele", "Rosewood-Walnut", "Walnut-Sapele"))

p = ggplot(summDF, aes(x=label, y=Mode)) + geom_point(shape=1)
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0)
p = p + geom_hline(yintercept=0, linetype=3) + coord_flip()
p = p + theme_bw2 + theme(axis.title.x = element_text(hjust=1)) 
p = p + ylab("d'") + theme(axis.title.x = element_text(hjust=1)) + xlab(NULL)
ggsave(filename=paste0(resDir, "HDIs_summ.pdf"), width=3.4252, height=3.4252)
write.table(summDF, paste0(resDir, "figures_data/df_summ.csv"), row.names=F, col.names=T)
              
summDFByType = summarizePostListDF(list(
    mcmcMat[,'b0']+mcmcMat[,'bB[2]'],
    mcmcMat[,'b0']+mcmcMat[,'bB[3]'],
    mcmcMat[,'b0']+mcmcMat[,'bB[1]']),
    labels = c("Professional", "Semi-pro", "Amateur"))

p = ggplot(summDFByType, aes(x=label, y=Mode)) + geom_point(shape=1)
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0)
p = p + geom_hline(yintercept=0, linetype=3) + coord_flip()
p = p + theme_bw2 + theme(axis.title.x = element_text(hjust=1)) 
p = p + ylab("d'") + theme(axis.title.x = element_text(hjust=1)) + xlab(NULL)
ggsave(filename=paste0(resDir, "HDIs_summ_by_type.pdf"), width=3.4252, height=3.4252)
write.table(summDF, paste0(resDir, "figures_data/df_summ_by_type.csv"), row.names=F, col.names=T)


summDFByTypeAndCmp = summarizePostListDF(list(
    mcmcMat[,'b0']+mcmcMat[,'bB[2]']+mcmcMat[,'bW[1]']+mcmcMat[,'bBxW[2,1]'],
    mcmcMat[,'b0']+mcmcMat[,'bB[2]']+mcmcMat[,'bW[2]']+mcmcMat[,'bBxW[2,2]'],
    mcmcMat[,'b0']+mcmcMat[,'bB[2]']+mcmcMat[,'bW[3]']+mcmcMat[,'bBxW[2,3]'],
    mcmcMat[,'b0']+mcmcMat[,'bB[3]']+mcmcMat[,'bW[1]']+mcmcMat[,'bBxW[3,1]'],
    mcmcMat[,'b0']+mcmcMat[,'bB[3]']+mcmcMat[,'bW[2]']+mcmcMat[,'bBxW[3,2]'],
    mcmcMat[,'b0']+mcmcMat[,'bB[3]']+mcmcMat[,'bW[3]']+mcmcMat[,'bBxW[3,3]'],
    mcmcMat[,'b0']+mcmcMat[,'bB[1]']+mcmcMat[,'bW[1]']+mcmcMat[,'bBxW[1,1]'],
    mcmcMat[,'b0']+mcmcMat[,'bB[1]']+mcmcMat[,'bW[2]']+mcmcMat[,'bBxW[1,2]'],
    mcmcMat[,'b0']+mcmcMat[,'bB[1]']+mcmcMat[,'bW[3]']+mcmcMat[,'bBxW[1,3]']),
    labels = c("Professional / Rosewood-Sapele",
        "Professional / Rosewood-Walnut",
        "Professional / Walnut-Sapele",
        "Semi-pro / Rosewood-Sapele",
        "Semi-pro / Rosewood-Walnut",
        "Semi-pro / Walnut-Sapele",
        "Amateur / Rosewood-Sapele",
        "Amateur / Rosewood-Walnut",
        "Amateur / Walnut-Sapele"))
summDFByTypeAndCmp$type = factor(rep(c("Professional", "Semi-pro", "Amateur"), each=3), levels=c("Professional", "Semi-pro", "Amateur"))
summDFByTypeAndCmp$cmp = rep(c("Braz. Rsw. vs Sapele", "Braz. Rsw. vs Walnut", "Sapele vs Walnut"), 3)

p = ggplot(summDFByTypeAndCmp, aes(x=cmp, y=Mode, fill=type))
p = p + geom_bar(stat="identity", position=position_dodge(0.9))
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), position=position_dodge(0.9), width=0.5)
p = p +  scale_fill_manual(name="", values=threeCol)
p = p + ylab(dpText) + xlab("Guitars") + theme_bw2
p = p + theme(axis.text.x = element_text(angle = 45, hjust = 1), legend.position="top", legend.justification=c(0,1))
ggsave(filename=paste0(resDir, "HDIs_summ_by_type_and_guitars.pdf"), width=3.4252+0.5, height=3.4252+1)
write.table(summDFByTypeAndCmp, paste0(resDir, "figures_data/df_summ_by_type_and_guitars.csv"), row.names=F, col.names=T)

##
postByProfCnd = list(pro_RS=mcmcMat[,'b0']+mcmcMat[,'bB[2]']+mcmcMat[,'bW[1]']+mcmcMat[,'bBxW[2,1]'],
    pro_RW=mcmcMat[,'b0']+mcmcMat[,'bB[2]']+mcmcMat[,'bW[2]']+mcmcMat[,'bBxW[2,2]'],
    pro_WS=mcmcMat[,'b0']+mcmcMat[,'bB[2]']+mcmcMat[,'bW[3]']+mcmcMat[,'bBxW[2,3]'],
    semipro_RS=mcmcMat[,'b0']+mcmcMat[,'bB[3]']+mcmcMat[,'bW[1]']+mcmcMat[,'bBxW[3,1]'],
    semipro_RW=mcmcMat[,'b0']+mcmcMat[,'bB[3]']+mcmcMat[,'bW[2]']+mcmcMat[,'bBxW[3,2]'],
    semipro_WS=mcmcMat[,'b0']+mcmcMat[,'bB[3]']+mcmcMat[,'bW[3]']+mcmcMat[,'bBxW[3,3]'],
    amat_RS=mcmcMat[,'b0']+mcmcMat[,'bB[1]']+mcmcMat[,'bW[1]']+mcmcMat[,'bBxW[1,1]'],
    amat_RW=mcmcMat[,'b0']+mcmcMat[,'bB[1]']+mcmcMat[,'bW[2]']+mcmcMat[,'bBxW[1,2]'],
    amat_WS=mcmcMat[,'b0']+mcmcMat[,'bB[1]']+mcmcMat[,'bW[3]']+mcmcMat[,'bBxW[1,3]'])

cntrInt = list(pro_semipro_RS_RW = (postByProfCnd[["pro_RS"]]-postByProfCnd[["pro_RW"]])-(postByProfCnd[["semipro_RS"]]-postByProfCnd[["semipro_RW"]]),
               pro_semipro_RS_WS = (postByProfCnd[["pro_RS"]]-postByProfCnd[["pro_WS"]])-(postByProfCnd[["semipro_RS"]]-postByProfCnd[["semipro_WS"]]),
               pro_semipro_RW_WS = (postByProfCnd[["pro_RW"]]-postByProfCnd[["pro_WS"]])-(postByProfCnd[["semipro_RW"]]-postByProfCnd[["semipro_WS"]]),
               pro_amat_RS_RW = (postByProfCnd[["pro_RS"]]-postByProfCnd[["pro_RW"]])-(postByProfCnd[["amat_RS"]]-postByProfCnd[["amat_RW"]]),
               pro_amat_RS_WS = (postByProfCnd[["pro_RS"]]-postByProfCnd[["pro_WS"]])-(postByProfCnd[["amat_RS"]]-postByProfCnd[["amat_WS"]]),
               pro_amat_RW_WS = (postByProfCnd[["pro_RW"]]-postByProfCnd[["pro_WS"]])-(postByProfCnd[["amat_RW"]]-postByProfCnd[["amat_WS"]]),
               semipro_amat_RS_RW = (postByProfCnd[["semipro_RS"]]-postByProfCnd[["semipro_RW"]])-(postByProfCnd[["amat_RS"]]-postByProfCnd[["amat_RW"]]),
               semipro_amat_RS_WS = (postByProfCnd[["semipro_RS"]]-postByProfCnd[["semipro_WS"]])-(postByProfCnd[["amat_RS"]]-postByProfCnd[["amat_WS"]]),
               semipro_amat_RW_WS = (postByProfCnd[["semipro_RW"]]-postByProfCnd[["semipro_WS"]])-(postByProfCnd[["amat_RW"]]-postByProfCnd[["amat_WS"]])
               )

pdf(paste0(resDir, "posterior_interactions.pdf"), width=size2c, height=size2c*1.5)
par(mfrow=c(3,3))
for (i in 1:length(cntrInt)){
    plotPost(cntrInt[[i]], main=names(cntrInt)[i], xlab=dpText)
}
dev.off()

pdf(paste0(resDir, "posterior_between.pdf"), width=size2c, heigh=size1c)
par(mfrow=c(1,3))
for (i in 1:length(cntrs_dp[["between"]])){
    plotPost(cntrs_dp[["between"]][[i]], main=names(cntrs_dp[["between"]])[i], xlab=dpText)
}
dev.off()

pdf(paste0(resDir, "posterior_within.pdf"), width=size1c, heigh=size2c)
par(mfrow=c(3,1))
for (i in 1:length(cntrs_dp[["within"]])){
    plotPost(cntrs_dp[["within"]][[i]], main=names(cntrs_dp[["within"]])[i], xlab=dpText)
}
dev.off()
    
cntrIntDF = summarizePostListDF(cntrInt, labels=c("pro-semipro_RS-RW",
                                                  "pro-semipro_RS-WS",
                                                  "pro-semipro_RW-WS",
                                                  "pro-amat_RS-RW",
                                                  "pro-amat_RS-WS",
                                                  "pro-amat_RW-WS",
                                                  "semipro-amat_RS-RW",
                                                  "semipro-amat_RS-WS",
                                                  "semipro-amat_RW-WS"))
cntrIntDF$type = rep(c("Pro. vs Semi-pro.", "Pro. vs Amat.", "Semi-pro vs Amat."), each=3)
cntrIntDF$cnd = rep(c("R.S. vs R.W.", "R.S. vs W.S.", "R.W. vs W.S."), 3)

p = ggplot(cntrIntDF, aes(x=cnd, y=Mode)) + facet_wrap(~type)
p = p + geom_point(stat="identity", position=position_dodge(0.9))
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), position=position_dodge(0.9), width=0.5)
p = p + coord_flip()
p = p + ylab(dpText) + xlab("Contrast") + theme_bw2
p = p + geom_hline(yintercept=0, linetype=3)
p = p + geom_hline(yintercept=c(-0.2, 0.2), linetype=3, color="gray60")
ggsave(filename=paste0(resDir, "HDIs_interaction_contrasts.pdf"), width=3.4252*2, height=3.4252)


t2 = Sys.time()
print(t2-t1)


