 
summarizePostListDF = function(paramSampleVecList, 
    compVal=NULL, ROPE=NULL, credMass=0.95, labels=rep("", length(paramSampleVecList))){

    postFrame = data.frame()
    for (i in 1:length(paramSampleVecList)){
        paramSampleVec = paramSampleVecList[[i]]
        meanParam = mean(paramSampleVec)
        medianParam = median(paramSampleVec)
        dres = density(paramSampleVec)
        modeParam = dres$x[which.max(dres$y)]
        mcmcEffSz = round(effectiveSize(paramSampleVec), 1)
        names(mcmcEffSz) = NULL
        hdiLim = HDIofMCMC(paramSampleVec, credMass=credMass)
        if (!is.null(compVal)) {
            pcgtCompVal = (100 * sum(paramSampleVec > compVal) 
                           / length(paramSampleVec))
        } else {
            compVal=NA
            pcgtCompVal=NA
        }
        if (!is.null(ROPE)) {
            pcltRope = (100 * sum(paramSampleVec < ROPE[1]) 
                        / length(paramSampleVec))
            pcgtRope = (100 * sum(paramSampleVec > ROPE[2]) 
                        / length(paramSampleVec))
            pcinRope = 100-(pcltRope+pcgtRope)
        } else { 
            ROPE = c(NA,NA)
            pcltRope=NA 
            pcgtRope=NA 
            pcinRope=NA 
        }
        thisFrame = data.frame(Mean=meanParam, Median=medianParam, Mode=modeParam, 
            ESS=mcmcEffSz,
            HDImass=credMass, HDIlow=hdiLim[1], HDIhigh=hdiLim[2], 
            CompVal=compVal, PcntGtCompVal=pcgtCompVal, 
            ROPElow=ROPE[1], ROPEhigh=ROPE[2],
            PcntLtROPE=pcltRope, PcntInROPE=pcinRope, PcntGtROPE=pcgtRope, label=labels[i])
        postFrame = rbind(postFrame, thisFrame)
    }
    
  return(postFrame)
}


summarizePostDF = function(paramSampleVec, 
    compVal=NULL, ROPE=NULL, credMass=0.95, label=""){

    postFrame = data.frame()
    meanParam = mean(paramSampleVec)
    medianParam = median(paramSampleVec)
    dres = density(paramSampleVec)
    modeParam = dres$x[which.max(dres$y)]
    mcmcEffSz = round(effectiveSize(paramSampleVec), 1)
    names(mcmcEffSz) = NULL
    hdiLim = HDIofMCMC(paramSampleVec, credMass=credMass)
    if (!is.null(compVal)) {
        pcgtCompVal = (100 * sum(paramSampleVec > compVal) 
                       / length(paramSampleVec))
    } else {
        compVal=NA
        pcgtCompVal=NA
    }
    if (!is.null(ROPE)) {
        pcltRope = (100 * sum(paramSampleVec < ROPE[1]) 
                    / length(paramSampleVec))
        pcgtRope = (100 * sum(paramSampleVec > ROPE[2]) 
                    / length(paramSampleVec))
        pcinRope = 100-(pcltRope+pcgtRope)
    } else { 
        ROPE = c(NA,NA)
        pcltRope=NA 
        pcgtRope=NA 
        pcinRope=NA 
    }
    postFrame = data.frame(Mean=meanParam, Median=medianParam, Mode=modeParam, 
        ESS=mcmcEffSz,
        HDImass=credMass, HDIlow=hdiLim[1], HDIhigh=hdiLim[2], 
        CompVal=compVal, PcntGtCompVal=pcgtCompVal, 
        ROPElow=ROPE[1], ROPEhigh=ROPE[2],
        PcntLtROPE=pcltRope, PcntInROPE=pcinRope, PcntGtROPE=pcgtRope, label=label)
    
  return(postFrame)
}


summarizePostDFDF = function(mcmcDF, mcmcName="vals", groupingFactor=NULL, 
    compVal=NULL, ROPE=NULL, credMass=0.95){

    postFrame = data.frame()
    mcmcDF[,groupingFactor] = factor(mcmcDF[,groupingFactor], exclude=NULL)
    levs = levels(mcmcDF[,groupingFactor])
    nLev = length(levels(mcmcDF[,groupingFactor]))
    for (i in 1:nLev){
        thisLev = levs[i]
        paramSampleVec = mcmcDF[mcmcDF[,groupingFactor] == thisLev, mcmcName]
        meanParam = mean(paramSampleVec)
        medianParam = median(paramSampleVec)
        dres = density(paramSampleVec)
        modeParam = dres$x[which.max(dres$y)]
        mcmcEffSz = round(effectiveSize(paramSampleVec), 1)
        names(mcmcEffSz) = NULL
        hdiLim = HDIofMCMC(paramSampleVec, credMass=credMass)
        if (!is.null(compVal)) {
            pcgtCompVal = (100 * sum(paramSampleVec > compVal) 
                           / length(paramSampleVec))
        } else {
            compVal=NA
            pcgtCompVal=NA
        }
        if (!is.null(ROPE)) {
            pcltRope = (100 * sum(paramSampleVec < ROPE[1]) 
                        / length(paramSampleVec))
            pcgtRope = (100 * sum(paramSampleVec > ROPE[2]) 
                        / length(paramSampleVec))
            pcinRope = 100-(pcltRope+pcgtRope)
        } else { 
            ROPE = c(NA,NA)
            pcltRope=NA 
            pcgtRope=NA 
            pcinRope=NA 
        }
        thisFrame = data.frame(Mean=meanParam, Median=medianParam, Mode=modeParam, 
            ESS=mcmcEffSz,
            HDImass=credMass, HDIlow=hdiLim[1], HDIhigh=hdiLim[2], 
            CompVal=compVal, PcntGtCompVal=pcgtCompVal, 
            ROPElow=ROPE[1], ROPEhigh=ROPE[2],
            PcntLtROPE=pcltRope, PcntInROPE=pcinRope, PcntGtROPE=pcgtRope, label=thisLev)
        postFrame = rbind(postFrame, thisFrame)
    }
    
  return(postFrame)
}
