genMCMCAov1Btw1WtnRobust = function(datFrm, yName, xBetweenName, xWithinName,
    xSubjectName, numSavedSteps=50000, thinSteps=1) { 
  #------------------------------------------------------------------------------
  # THE DATA.
  # Convert data file columns to generic x,y variable names for model:
  y = as.numeric(datFrm[,yName])
  xBetween = as.numeric(as.factor(datFrm[,xBetweenName]))
  xBetweenLvl =  levels(as.factor(datFrm[,xBetweenName]))
  NxBetweenLvl = length(unique(xBetween))
  xWithin = as.numeric(as.factor(datFrm[,xWithinName]))
  xWithinLvl =  levels(as.factor(datFrm[,xWithinName]))
  NxWithinLvl = length(unique(xWithin))
  xSubject = as.numeric(as.factor(datFrm[,xSubjectName]))
  xSubjectLvl =  levels(as.factor(datFrm[,xSubjectName]))
  NxSubjectLvl = length(unique(xSubject))
  # between-subject factor level of each subject:
  xBetweenOfSubject = aggregate(xBetween, list(xSubject), FUN=unique)$x
  Ntotal = length(y)
  # Compute scale properties of data, for passing into prior to make the prior
  # vague on the scale of the data. 
  # For prior on baseline, etc.:
  yMean = mean(y)
  ySD = sd(y)
  # For hyper-prior on deflections:
  agammaShRa = unlist(gammaShRaFromModeSD(mode=sd(y)/2, sd=2*sd(y)))
  # Specify the data in a list for sending to JAGS:
  dataList = list(
    y = y,
    xBetween = xBetween,
    NxBetweenLvl = NxBetweenLvl,
    xWithin = xWithin,
    NxWithinLvl = NxWithinLvl,
    xSubject = xSubject,
    NxSubjectLvl = NxSubjectLvl,
    xBetweenOfSubject = xBetweenOfSubject,
    Ntotal = Ntotal,
    # data properties for scaling the prior:
    yMean = yMean,
    ySD = ySD,
    agammaShRa = agammaShRa 
)
  #------------------------------------------------------------------------------
  # THE MODEL.
  modelString = "
  model {
    for (r in 1:Ntotal) {
      y[r] ~ dt(mu[r], 1/sigma^2, nu)
      mu[r] <- (a0 + aB[xBetween[r]] + aW[xWithin[r]] + aS[xSubject[r]] 
                 + aBxW[xBetween[r], xWithin[r]])
      y.err[r] <- y[r]-mu[r]
    }
    nu <- nuMinusOne+1
    nuMinusOne ~  dexp(1/29) 
    sigma ~ dunif(ySD/100, ySD*10)
    a0 ~ dnorm(yMean, 1/(ySD*5)^2)
    for (i in 1:NxBetweenLvl) { aB[i] ~ dnorm(0.0, 1/sigmaB^2) }
    sigmaB ~ dgamma(agammaShRa[1],agammaShRa[2])
    for (j in 1:NxWithinLvl) { aW[j] ~ dnorm(0.0, 1/sigmaW^2) }
    sigmaW ~ dgamma(agammaShRa[1],agammaShRa[2])
    for (k in 1:NxSubjectLvl) { aS[k] ~ dnorm(0.0, 1/sigmaS^2) }
    sigmaS ~ dgamma(agammaShRa[1],agammaShRa[2])
    for (i in 1:NxBetweenLvl) { for (j in 1:NxWithinLvl) {
      aBxW[i,j] ~ dnorm(0.0, 1/sigmaBxW^2)
    } }
    sigmaBxW ~ dgamma(agammaShRa[1],agammaShRa[2])


    s.y <- sd(y.err[])
    s.B <- sd(bB[])
    s.W <- sd(bW[])
    s.BxW <- sd(bBxW[,])
    s.S <- sd(bS[])

    s.aB <- sd(aB[])
    s.aW <- sd(aW[])
    s.aBxW <- sd(aBxW[,])
    s.aS <- sd(aS[])
    # For converting deflections to sum-to-zero:
    # JAGS doesn't like vectorized indices in mean(), so we use a 3D array.
    # Klunky, but it works.
    # Put predicted values into a 3D array, with empty cells set to zero:
    for (k in 1:NxSubjectLvl) { 
      for (i in 1:NxBetweenLvl) {
        for (j in 1:NxWithinLvl) {
          mSxBxW[k,i,j] <- ifelse(xBetweenOfSubject[k]==i,
                                   a0 + aB[xBetweenOfSubject[k]] + aW[j] 
                                    + aBxW[xBetweenOfSubject[k],j] + aS[k], 0)
    } } }
    # Also put predicted values into a 2D array:
    for (k in 1:NxSubjectLvl) { for (j in 1:NxWithinLvl) {
      mSxW[k,j] <- (a0 + aB[xBetweenOfSubject[k]] + aW[j] 
                     + aBxW[xBetweenOfSubject[k],j] + aS[k])
    } }
    # Convert deflections to sum-to-zero:
    for (i in 1:NxBetweenLvl) { for (j in 1:NxWithinLvl) { 
      mBxW[i,j] <- (sum(mSxBxW[1:NxSubjectLvl,i,j]) 
                     / sum(mSxBxW[1:NxSubjectLvl,i,j]!=0))
      bBxW[i,j] <- mBxW[i,j] - mB[i] - mW[j] + m
    } }
    for (k in 1:NxSubjectLvl) {
      mS[k] <- mean(mSxW[k,1:NxWithinLvl])
      bS[k] <- mS[k] - mB[xBetweenOfSubject[k]]
    }
    m <- mean(mBxW[1:NxBetweenLvl,1:NxWithinLvl])
    b0 <- m
    for (i in 1:NxBetweenLvl) {
      mB[i] <- mean(mBxW[i,1:NxWithinLvl])
      bB[i] <- mB[i] - m
    }
    for (j in 1:NxWithinLvl) {
      mW[j] <- mean(mBxW[1:NxBetweenLvl,j])
      bW[j] <- mW[j] - m
    }
        
  }
  " # close quote for modelstring
  fPath = tempfile(fileext=".jag")
  writeLines(modelString, con=fPath)

  ## ------------------------------------------------------------------------------
  ## INTIALIZE THE CHAINS.
  initsFunction = function(chain){
      .RNG.seed = c(14, 10, 85, 2017)[chain]
      .RNG.name = c("base::Super-Duper",
                     "base::Wichmann-Hill",
                     "base::Marsaglia-Multicarry",
                     "base::Mersenne-Twister")[chain]
      return(list(.RNG.seed=.RNG.seed,
                  .RNG.name=.RNG.name))
 }
  #------------------------------------------------------------------------------
  # RUN THE CHAINS

  parameters = c("mSxW", "b0",  "bB",  "bW",  "bBxW", "bS", 
    "sigma", "sigmaB", "sigmaW", "sigmaBxW", "sigmaS","nu",
    "s.y", "s.B", "s.W", "s.BxW", "s.S",
    "s.aB", "s.aW", "s.aBxW", "s.aS")
  
  ## Using runjags:
  adaptSteps = 1000 
  burnInSteps = 2000 
  require(parallel)
  ## nCores = detectCores()
  ## if (!is.finite(nCores)) {nCores = 1} 
  ## nChains = min(4, max(1, (nCores - 1)))
  nChains = 4
  
  runJagsOut = run.jags(method="parallel",
                          model=fPath, 
                          monitor=parameters, 
                          data=dataList,  
                          inits=initsFunction, 
                          n.chains=nChains,
                          adapt=adaptSteps,
                          burnin=burnInSteps, 
                          sample=ceiling(numSavedSteps/nChains),
                          thin=thinSteps,
                          summarise=FALSE,
                          plots=FALSE)
  
  codaSamples = as.mcmc.list(runJagsOut)
  return(codaSamples)
}

#===============================================================================

smryMCMCAov1Btw1WtnRobust = function(codaSamples, datFrm=NULL, 
                      xBetweenName=NULL, xWithinName=NULL, xSubjectName=NULL,
                      xBetweenContrasts=NULL, 
                      xWithinContrasts=NULL, 
                      xBetweenWithinContrasts=NULL) {
  # All single parameters:
  parameterNames = varnames(codaSamples) 
  if (!is.null(datFrm) & !is.null(xBetweenName) & !is.null(xWithinName) 
       & !is.null(xSubjectName)) {
    xBetweenLvl = levels(as.factor(datFrm[,xBetweenName]))
    xWithinLvl = levels(as.factor(datFrm[,xWithinName]))
    xSubjectLvl = levels(as.factor(datFrm[,xSubjectName]))
  }
  summaryInfo = NULL
  mcmcMat = as.matrix(codaSamples,chains=TRUE)
  for (parName in parameterNames) {
    summaryInfo = rbind(summaryInfo, summarizePost(mcmcMat[,parName]))
    thisRowName = parName
    if (!is.null(datFrm) & !is.null(xBetweenName) & !is.null(xWithinName) 
         & !is.null(xSubjectName)) {
      # For row name, extract numeric digits from parameter name. E.g., if
      # parameter name is "blah[12,34]" then pull out blah, 12 and 34:
      strparts = unlist(strsplit(parName, "\\[|,|\\]"))
      # if there are only the param name and a single index:
      if (length(strparts)==2) { 
        # if param name refers to Within:
        if (substr(strparts[1],nchar(strparts[1]),nchar(strparts[1]))=="W") { 
          thisRowName = paste(thisRowName, xWithinLvl[as.numeric(strparts[2])])
        }
        # if param name refers to factor Between:
        if (substr(strparts[1],nchar(strparts[1]),nchar(strparts[1]))=="B") { 
          thisRowName = paste(thisRowName, xBetweenLvl[as.numeric(strparts[2])])
        }
        # if param name refers to factor Subject:
        if (substr(strparts[1],nchar(strparts[1]),nchar(strparts[1]))=="S") { 
          thisRowName = paste(thisRowName, xSubjectLvl[as.numeric(strparts[2])])
        }
      }
      # if there are the param name and two indices:
      if (length(strparts)==3) { 
        if (substr(strparts[1],nchar(strparts[1])-2,nchar(strparts[1]))=="SxW") { 
          thisRowName = paste(thisRowName, 
                               xSubjectLvl[as.numeric(strparts[2])], 
                               xWithinLvl[as.numeric(strparts[3])])
        }
        if (substr(strparts[1],nchar(strparts[1])-2,nchar(strparts[1]))=="BxW") { 
          thisRowName = paste(thisRowName, 
                               xBetweenLvl[as.numeric(strparts[2])], 
                               xWithinLvl[as.numeric(strparts[3])])
        }
      }
    }
    rownames(summaryInfo)[NROW(summaryInfo)] = thisRowName
  }
  # Begin contrasts:
  if (!is.null(xBetweenContrasts) | !is.null(xWithinContrasts) 
       | !is.null(xBetweenWithinContrasts)) {
    if (is.null(datFrm) | is.null(xBetweenName) | is.null(xWithinName)) {
      show(" *** YOU MUST SPECIFY THE DATA FILE AND FACTOR NAMES TO DO CONTRASTS. ***\n")
    } else {
      
      xBetween = as.numeric(as.factor(datFrm[,xBetweenName]))
      xBetweenLvl = levels(as.factor(datFrm[,xBetweenName]))
      xWithin = as.numeric(as.factor(datFrm[,xWithinName]))
      xWithinLvl = levels(as.factor(datFrm[,xWithinName]))
      # xBetween contrasts:
      if (!is.null(xBetweenContrasts)) {
        for (cIdx in 1:length(xBetweenContrasts)) {
          thisContrast = xBetweenContrasts[[cIdx]]
          left = right = rep(FALSE,length(xBetweenLvl))
          for (nIdx in 1:length(thisContrast[[1]])) { 
            left = left | xBetweenLvl==thisContrast[[1]][nIdx]
          }
          left = normalize(left)
          for (nIdx in 1:length(thisContrast[[2]])) { 
            right = right | xBetweenLvl==thisContrast[[2]][nIdx]
          }
          right = normalize(right)
          contrastCoef = matrix(left-right, ncol=1)
          postContrast = (mcmcMat[,paste("bB[",1:length(xBetweenLvl),"]",sep="")] 
                           %*% contrastCoef)
          summaryInfo = rbind(summaryInfo, 
                               summarizePost(postContrast,
                                              compVal=thisContrast$compVal,
                                              ROPE=thisContrast$ROPE))
          rownames(summaryInfo)[NROW(summaryInfo)] = (
            paste(paste(thisContrast[[1]],collapse=""), ".v.",
                   paste(thisContrast[[2]],collapse=""),sep=""))
        }
      } # end between contrasts.
      # xWithin contrasts:
      if (!is.null(xWithinContrasts)) {
        for (cIdx in 1:length(xWithinContrasts)) {
          thisContrast = xWithinContrasts[[cIdx]]
          left = right = rep(FALSE,length(xWithinLvl))
          for (nIdx in 1:length(thisContrast[[1]])) { 
            left = left | xWithinLvl==thisContrast[[1]][nIdx]
          }
          left = normalize(left)
          for (nIdx in 1:length(thisContrast[[2]])) { 
            right = right | xWithinLvl==thisContrast[[2]][nIdx]
          }
          right = normalize(right)
          contrastCoef = matrix(left-right, ncol=1)
          postContrast = (mcmcMat[,paste("bW[",1:length(xWithinLvl),"]",sep="")] 
                           %*% contrastCoef)
          summaryInfo = rbind(summaryInfo, 
                               summarizePost(postContrast,
                                              compVal=thisContrast$compVal,
                                              ROPE=thisContrast$ROPE))
          rownames(summaryInfo)[NROW(summaryInfo)] = (
            paste(paste(thisContrast[[1]],collapse=""), ".v.",
                   paste(thisContrast[[2]],collapse=""),sep=""))
        }
      } # end within contrasts.
      # interaction contrasts:
      if (!is.null(xBetweenWithinContrasts)) {
        for (cIdx in 1:length(xBetweenWithinContrasts)) {
          thisContrast = xBetweenWithinContrasts[[cIdx]]
          # Between contrast:
          Bcontrast = thisContrast[[1]]
          BcontrastLeft = Bcontrast[[1]]
          BcontrastRight = Bcontrast[[2]]
          left = right = rep(FALSE,length(xBetweenLvl))
          for (nIdx in 1:length(BcontrastLeft)) { 
            left = left | xBetweenLvl==BcontrastLeft[nIdx]
          }
          left = normalize(left)
          for (nIdx in 1:length(BcontrastRight)) { 
            right = right | xBetweenLvl==BcontrastRight[nIdx]
          }
          right = normalize(right)
          BcontrastCoef = left-right
          # Within contrast:
          Wcontrast = thisContrast[[2]]
          WcontrastLeft = Wcontrast[[1]]
          WcontrastRight = Wcontrast[[2]]
          left = right = rep(FALSE,length(xWithinLvl))
          for (nIdx in 1:length(WcontrastLeft)) { 
            left = left | xWithinLvl==WcontrastLeft[nIdx]
          }
          left = normalize(left)
          for (nIdx in 1:length(WcontrastRight)) { 
            right = right | xWithinLvl==WcontrastRight[nIdx]
          }
          right = normalize(right)
          WcontrastCoef = left-right
          # interaction contrast:
          contrastCoef = cbind(as.vector(
            outer(BcontrastCoef, WcontrastCoef)))
          postContrast = (mcmcMat[,substr(colnames(mcmcMat),1,5)=="bBxW["] 
                           %*% contrastCoef)
          summaryInfo = rbind(summaryInfo, 
                               summarizePost(postContrast,
                                              compVal=thisContrast$compVal,
                                              ROPE=thisContrast$ROPE))
          rownames(summaryInfo)[NROW(summaryInfo)] = (
            paste(paste(paste(thisContrast[[1]][[1]],collapse=""), 
                          ".v.",
                          paste(thisContrast[[1]][[2]],collapse=""),sep=""),
                   ".x.",
                   paste(paste(thisContrast[[2]][[1]],collapse=""), 
                          ".v.",
                          paste(thisContrast[[2]][[2]],collapse=""),sep=""),
                   sep=""))
        }
      } # end interaction contrasts
    }
  }
  # Save results:
  ## if (!is.null(saveName)) {
  ##   write.csv(summaryInfo, file=paste(saveName,"SummaryInfo.csv",sep=""))
  ## }
  return(summaryInfo)
}

#===============================================================================


getContrastsAov1Btw1WtnRobust = function(codaSamples, 
    datFrm, yName=NULL,
    xBetweenName=NULL, xWithinName=NULL, xSubjectName=NULL,
    xBetweenContrasts=NULL, 
    xWithinContrasts=NULL, 
    xBetweenWithinContrasts=NULL) {
    
    mcmcMat = as.matrix(codaSamples,chains=TRUE)
    chainLength = NROW(mcmcMat)
    chainSub = round(seq(1,chainLength,length=20))
    y = datFrm[,yName]
    xBetween = as.numeric(as.factor(datFrm[,xBetweenName]))
    xBetweenLvl = levels(as.factor(datFrm[,xBetweenName]))
    xWithin = as.numeric(as.factor(datFrm[,xWithinName]))
    xWithinLvl = levels(as.factor(datFrm[,xWithinName]))
    xSubject = as.numeric(as.factor(datFrm[,xSubjectName]))
    xSubjectLvl = levels(as.factor(datFrm[,xSubjectName]))

    postContrastListWtn = list()
    postContrastListBtw = list()
    postContrastListBtwWtn = list()

    # plot contrasts:
    if (!is.null(xBetweenContrasts) | !is.null(xWithinContrasts) 
        | !is.null(xBetweenWithinContrasts)) {
        if (is.null(datFrm) | is.null(xBetweenName) | is.null(xWithinName)) {
            show(" *** YOU MUST SPECIFY THE DATA FILE AND FACTOR NAMES TO DO CONTRASTS. ***\n")
        } else {
            
            xBetween = as.numeric(as.factor(datFrm[,xBetweenName]))
            xBetweenLvl = levels(as.factor(datFrm[,xBetweenName]))
            xWithin = as.numeric(as.factor(datFrm[,xWithinName]))
            xWithinLvl = levels(as.factor(datFrm[,xWithinName]))
            
            # xBetween contrasts:
            if (!is.null(xBetweenContrasts)) {
                for (cIdx in 1:length(xBetweenContrasts)) {
                    thisContrast = xBetweenContrasts[[cIdx]]
                    left = right = rep(FALSE,length(xBetweenLvl))
                    for (nIdx in 1:length(thisContrast[[1]])) { 
                        left = left | xBetweenLvl==thisContrast[[1]][nIdx]
                    }
                    left = normalize(left)
                    for (nIdx in 1:length(thisContrast[[2]])) { 
                        right = right | xBetweenLvl==thisContrast[[2]][nIdx]
                    }
                    right = normalize(right)
                    contrastCoef = matrix(left-right, ncol=1)

                    postContrast = (mcmcMat[,paste("bB[",1:length(xBetweenLvl),"]",sep="")] 
                                    %*% contrastCoef)
                  
                    postContrastListBtw[[paste(paste(thisContrast[[1]],collapse="."), "-vs-", paste(thisContrast[[2]],collapse="."), sep='')]] = postContrast
                    
                }
            } # end between contrasts.
            
            # xWithin contrasts:
            if (!is.null(xWithinContrasts)) {
                for (cIdx in 1:length(xWithinContrasts)) {
                    thisContrast = xWithinContrasts[[cIdx]]
                    left = right = rep(FALSE,length(xWithinLvl))
                    for (nIdx in 1:length(thisContrast[[1]])) { 
                        left = left | xWithinLvl==thisContrast[[1]][nIdx]
                    }
                    left = normalize(left)
                    for (nIdx in 1:length(thisContrast[[2]])) { 
                        right = right | xWithinLvl==thisContrast[[2]][nIdx]
                    }
                    right = normalize(right)
                    contrastCoef = matrix(left-right, ncol=1)
                    postContrast = (mcmcMat[,paste("bW[",1:length(xWithinLvl),"]",sep="")] 
                                    %*% contrastCoef)
              
                    postContrastListWtn[[paste(paste(thisContrast[[1]],collapse="."), "-vs-", paste(thisContrast[[2]],collapse="."), sep='')]] = postContrast
                   
                }
            } # end within contrasts.
            
            ## interaction contrasts:
            if (!is.null(xBetweenWithinContrasts)) {
                for (cIdx in 1:length(xBetweenWithinContrasts)) {
                    thisContrast = xBetweenWithinContrasts[[cIdx]]
                    ## Between contrast:
                    Bcontrast = thisContrast[[1]]
                    BcontrastLeft = Bcontrast[[1]]
                    BcontrastRight = Bcontrast[[2]]
                    left = right = rep(FALSE,length(xBetweenLvl))
                    for (nIdx in 1:length(BcontrastLeft)) { 
                        left = left | xBetweenLvl==BcontrastLeft[nIdx]
                    }
                    left = normalize(left)
                    for (nIdx in 1:length(BcontrastRight)) { 
                        right = right | xBetweenLvl==BcontrastRight[nIdx]
                    }
                    right = normalize(right)
                    BcontrastCoef = left-right
                    ## Within contrast:
                    Wcontrast = thisContrast[[2]]
                    WcontrastLeft = Wcontrast[[1]]
                    WcontrastRight = Wcontrast[[2]]
                    left = right = rep(FALSE,length(xWithinLvl))
                    for (nIdx in 1:length(WcontrastLeft)) { 
                        left = left | xWithinLvl==WcontrastLeft[nIdx]
                    }
                    left = normalize(left)
                    for (nIdx in 1:length(WcontrastRight)) { 
                        right = right | xWithinLvl==WcontrastRight[nIdx]
                    }
                    right = normalize(right)
                    WcontrastCoef = left-right
                    ## interaction contrast:
                    contrastCoef = cbind(as.vector(
                        outer(BcontrastCoef, WcontrastCoef)))
                    postContrast = (mcmcMat[,substr(colnames(mcmcMat),1,5)=="bBxW["] 
                                    %*% contrastCoef)
                  
                    postContrastListBtwWtn[[paste(paste(thisContrast[[1]],collapse="."), "-vs-", paste(thisContrast[[2]],collapse="."), sep='')]] = postContrast
                    
                }
            } # end interaction contrasts
            
            
        }
    }
    postContrastList = list(between=postContrastListBtw, within=postContrastListWtn, between_within=postContrastListBtwWtn)
    return(postContrastList)
    
}


plotPostPredAov1Btw1WtnRobust = function(codaSamples, 
    datFrm, yName="y",
    xBetweenName=NULL, xWithinName=NULL, xSubjectName=NULL,
                                         xBetweenLevel=NULL) {
    
    mcmcMat = as.matrix(codaSamples,chains=TRUE)
    chainLength = NROW(mcmcMat)
    chainSub = round(seq(1,chainLength,length=20))
    y = datFrm[,yName]
    xBetween = as.numeric(as.factor(datFrm[,xBetweenName]))
    xBetweenLvl = levels(as.factor(datFrm[,xBetweenName]))
    xWithin = as.numeric(as.factor(datFrm[,xWithinName]))
    xWithinLvl = levels(as.factor(datFrm[,xWithinName]))
    xSubject = as.numeric(as.factor(datFrm[,xSubjectName]))
    xSubjectLvl = levels(as.factor(datFrm[,xSubjectName]))

   
    Bidx = which(xBetweenLvl == xBetweenLevel)
    par(mar=c(4,4,2,1), mgp=c(3,1,0))
    plot(-10,-10, 
         xlim=c(0.2,length(xWithinLvl)+0.1), 
         xlab=paste(xWithinName,xBetweenName,sep="\n"), 
         xaxt="n", ylab=yName,
         ylim=c(min(y)-0.2*(max(y)-min(y)),max(y)+0.2*(max(y)-min(y))),
         main="Data with Post. Pred.")
    axis(1, at=1:length(xWithinLvl), tick=FALSE,
         lab=paste(xWithinLvl, xBetweenLvl[Bidx], sep="\n"))
    ## plot subject data:
    SidxVec = unique(xSubject[ xBetween==Bidx ])
    for (Sidx in SidxVec) {
        yVals = NULL
        yVals2 = NULL
        for (Widx in 1:length(xWithinLvl)) {
            yVals = c(yVals, y[xSubject==Sidx & xWithin==Widx][1])
            yVals2 = c(yVals2, y[xSubject==Sidx & xWithin==Widx][2])
        }
        plotCol="red"
        lines(1:length(xWithinLvl)+runif(length(xWithinLvl),-0.05,0.05), 
              yVals, type="o", pch=1, cex=1.5, col=plotCol, lty="solid")
        lines(1:length(xWithinLvl)+runif(length(xWithinLvl),-0.05,0.05), 
              yVals2, type="o", pch=1, cex=1.5, col="black", lty="solid")
        
    }
    ## superimpose posterior predictive distrib:
    for (Widx in 1:length(xWithinLvl)) {
        for (chnIdx in chainSub) {
            m = (mcmcMat[chnIdx,"b0"]
                 + mcmcMat[chnIdx,paste0("bB[",Bidx,"]")]
                 + mcmcMat[chnIdx,paste0("bW[",Widx,"]")]
                 + mcmcMat[chnIdx,paste0("bBxW[",Bidx,",",Widx,"]")])
            s = mcmcMat[chnIdx,"sigma"]
            n = mcmcMat[chnIdx,"nu"]
            
                                        #normlim = qnorm(c(0.025,0.975))
            tlim = qt( c(0.025,0.975) , df=n )
                                        #yl = m+normlim[1]*s
                                        #yh = m+normlim[2]*s
            yl = m+tlim[1]*s
            yh = m+tlim[2]*s
            ycomb=seq(yl,yh,length=201)
            yt = dt((ycomb-m)/s, df=n)
            yt = 0.67*yt/max(yt)
            lines(Widx-yt, ycomb, col="slateblue") 
        }
    }
    
}


getContrastsAov1Btw1WtnRobustDF = function(codaSamples, 
    datFrm, yName=NULL,
    xBetweenName=NULL, xWithinName=NULL, xSubjectName=NULL,
    xBetweenContrasts=NULL, 
    xWithinContrasts=NULL, 
    xBetweenWithinContrasts=NULL) {
    
    mcmcMat = as.matrix(codaSamples,chains=TRUE)
    chainLength = NROW(mcmcMat)
    chainSub = round(seq(1,chainLength,length=20))
    y = datFrm[,yName]
    xBetween = as.numeric(as.factor(datFrm[,xBetweenName]))
    xBetweenLvl = levels(as.factor(datFrm[,xBetweenName]))
    xWithin = as.numeric(as.factor(datFrm[,xWithinName]))
    xWithinLvl = levels(as.factor(datFrm[,xWithinName]))
    xSubject = as.numeric(as.factor(datFrm[,xSubjectName]))
    xSubjectLvl = levels(as.factor(datFrm[,xSubjectName]))

    postContrastListWtn = list()
    postContrastListBtw = list()
    postContrastListBtwWtn = list()

    # plot contrasts:
    if (!is.null(xBetweenContrasts) | !is.null(xWithinContrasts) 
        | !is.null(xBetweenWithinContrasts)) {
        if (is.null(datFrm) | is.null(xBetweenName) | is.null(xWithinName)) {
            show(" *** YOU MUST SPECIFY THE DATA FILE AND FACTOR NAMES TO DO CONTRASTS. ***\n")
        } else {
            
            xBetween = as.numeric(as.factor(datFrm[,xBetweenName]))
            xBetweenLvl = levels(as.factor(datFrm[,xBetweenName]))
            xWithin = as.numeric(as.factor(datFrm[,xWithinName]))
            xWithinLvl = levels(as.factor(datFrm[,xWithinName]))
            
            # xBetween contrasts:
            if (!is.null(xBetweenContrasts)) {
                for (cIdx in 1:length(xBetweenContrasts)) {
                    thisContrast = xBetweenContrasts[[cIdx]]
                    left = right = rep(FALSE,length(xBetweenLvl))
                    for (nIdx in 1:length(thisContrast[[1]])) { 
                        left = left | xBetweenLvl==thisContrast[[1]][nIdx]
                    }
                    left = normalize(left)
                    for (nIdx in 1:length(thisContrast[[2]])) { 
                        right = right | xBetweenLvl==thisContrast[[2]][nIdx]
                    }
                    right = normalize(right)
                    contrastCoef = matrix(left-right, ncol=1)

                    postContrast = (mcmcMat[,paste("bB[",1:length(xBetweenLvl),"]",sep="")] 
                                    %*% contrastCoef)
                  
                    postContrastListBtw[[paste(paste(thisContrast[[1]],collapse="."), "-vs-", paste(thisContrast[[2]],collapse="."), sep='')]] = postContrast
                    
                }
            } # end between contrasts.
            
            # xWithin contrasts:
            if (!is.null(xWithinContrasts)) {
                for (cIdx in 1:length(xWithinContrasts)) {
                    thisContrast = xWithinContrasts[[cIdx]]
                    left = right = rep(FALSE,length(xWithinLvl))
                    for (nIdx in 1:length(thisContrast[[1]])) { 
                        left = left | xWithinLvl==thisContrast[[1]][nIdx]
                    }
                    left = normalize(left)
                    for (nIdx in 1:length(thisContrast[[2]])) { 
                        right = right | xWithinLvl==thisContrast[[2]][nIdx]
                    }
                    right = normalize(right)
                    contrastCoef = matrix(left-right, ncol=1)
                    postContrast = (mcmcMat[,paste("bW[",1:length(xWithinLvl),"]",sep="")] 
                                    %*% contrastCoef)
              
                    postContrastListWtn[[paste(paste(thisContrast[[1]],collapse="."), "-vs-", paste(thisContrast[[2]],collapse="."), sep='')]] = postContrast
                   
                }
            } # end within contrasts.
            
            ## interaction contrasts:
            if (!is.null(xBetweenWithinContrasts)) {
                for (cIdx in 1:length(xBetweenWithinContrasts)) {
                    thisContrast = xBetweenWithinContrasts[[cIdx]]
                    ## Between contrast:
                    Bcontrast = thisContrast[[1]]
                    BcontrastLeft = Bcontrast[[1]]
                    BcontrastRight = Bcontrast[[2]]
                    left = right = rep(FALSE,length(xBetweenLvl))
                    for (nIdx in 1:length(BcontrastLeft)) { 
                        left = left | xBetweenLvl==BcontrastLeft[nIdx]
                    }
                    left = normalize(left)
                    for (nIdx in 1:length(BcontrastRight)) { 
                        right = right | xBetweenLvl==BcontrastRight[nIdx]
                    }
                    right = normalize(right)
                    BcontrastCoef = left-right
                    ## Within contrast:
                    Wcontrast = thisContrast[[2]]
                    WcontrastLeft = Wcontrast[[1]]
                    WcontrastRight = Wcontrast[[2]]
                    left = right = rep(FALSE,length(xWithinLvl))
                    for (nIdx in 1:length(WcontrastLeft)) { 
                        left = left | xWithinLvl==WcontrastLeft[nIdx]
                    }
                    left = normalize(left)
                    for (nIdx in 1:length(WcontrastRight)) { 
                        right = right | xWithinLvl==WcontrastRight[nIdx]
                    }
                    right = normalize(right)
                    WcontrastCoef = left-right
                    ## interaction contrast:
                    contrastCoef = cbind(as.vector(
                        outer(BcontrastCoef, WcontrastCoef)))
                    postContrast = (mcmcMat[,substr(colnames(mcmcMat),1,5)=="bBxW["] 
                                    %*% contrastCoef)
                  
                    postContrastListBtwWtn[[paste(paste(thisContrast[[1]],collapse="."), "-vs-", paste(thisContrast[[2]],collapse="."), sep='')]] = postContrast
                    
                }
            } # end interaction contrasts
            
            
        }
    }

    nrows = length(postContrastListBtw)*length(postContrastListBtw[[1]]) + length(postContrastListWtn)*length(postContrastListWtn[[1]]) + length(postContrastListBtwWtn)*length(postContrastListBtwWtn[[1]])
    nX = length(postContrastListBtw[[1]])
    vals = numeric(nrows)
    cntrNm = character(nrows)
    cntrTp = character(nrows)
    for (i in 1:length(postContrastListBtw)){
        thisCntrName = names(postContrastListBtw)[i]
        vals[(nX*(i-1)+1):(nX*i)] = postContrastListBtw[[thisCntrName]]
        cntrNm[(nX*(i-1)+1):(nX*i)] = rep(thisCntrName, nX)
        cntrTp[(nX*(i-1)+1):(nX*i)] = rep("between", nX)
    }
    cn = length(postContrastListBtw)
    for (i in 1:length(postContrastListWtn)){
        thisCntrName = names(postContrastListWtn)[i]
        vals[(nX*((i+cn)-1)+1):(nX*(i+cn))] = postContrastListWtn[[thisCntrName]]
        cntrNm[(nX*((i+cn)-1)+1):(nX*(i+cn))] = rep(thisCntrName, nX)
        cntrTp[(nX*((i+cn)-1)+1):(nX*(i+cn))] = rep("within", nX)
    }
    cn = length(postContrastListBtw) + length(postContrastListWtn)
    for (i in 1:length(postContrastListBtwWtn)){
        thisCntrName = names(postContrastListBtwWtn)[i]
        vals[(nX*((i+cn)-1)+1):(nX*(i+cn))] = postContrastListBtwWtn[[thisCntrName]]
        cntrNm[(nX*((i+cn)-1)+1):(nX*(i+cn))] = rep(thisCntrName, nX)
        cntrTp[(nX*((i+cn)-1)+1):(nX*(i+cn))] = rep("betweenXwithin", nX)
    }
    
    dfContrasts = data.frame(contrast=cntrNm, val=vals, contrastType=cntrTp)

    return(dfContrasts)
    
}
