t1 = Sys.time()
source("../DBDA2E-utilities_SC.R") #postprocessing utilities based on code of Kruschke
source("../DBDA2E-utilities_DF.R") #postprocessing utilities based on code of Kruschke
source("../Jags-Ymet-XmetThree-Mrobust-Subj.R") #jags model based on code of Kruschke
currDir = getwd()
setwd("../")
source("global_parameters.R")
setwd(currDir)
source("../utils.R")
#load libraries for multi-core parallel processing
library(foreach)
library(doParallel)
library(RColorBrewer)
library(dplyr)
registerDoParallel(cores=8)

##
updateMCMCSampling = TRUE


##directory where to save the results
resDir = "../../results/blinded_factor_scores_regression/"
dir.create(resDir, recursive=T, showWarnings=F)
dir.create(paste0(resDir, "MCMC_diagnostics"), recursive=T, showWarnings=F)
dir.create(paste0(resDir, "figures_data"), recursive=T, showWarnings=F)
## load data
dat = read.table("../../derived_datasets/blinded_ratings_with_EFA_scores.csv", header=T)
## set parameters for MCMC sampling
numSavedStepsRegMulti = 100000
thinStepsRegMulti = 10

## #############################################
## Multiple regression: overall ~ factor scores
## #############################################

if (updateMCMCSampling == TRUE | file.exists(paste0(resDir, "MCMC_overall.RDS")) == FALSE){
    mcmcCodaOverall = genMCMCYMetXMetThreeMRobustSubj(data=dat, xName=c("F1","F2", "F3"), yName="overall", 
        numSavedSteps=numSavedStepsRegMulti, thinSteps=thinStepsRegMulti)
    saveRDS(mcmcCodaOverall, file=paste0(resDir, "MCMC_overall.RDS"), compress="xz")
} else {
    mcmcCodaOverall = readRDS(paste0(resDir, "MCMC_overall.RDS"))
}

mcmcMatOverall = as.matrix(mcmcCodaOverall, chains=T)

parToPlot = c("zbeta0mu", "zbeta1mu", "zbeta2mu", "zbeta3mu",
              "beta0mu", "beta1mu",  "beta2mu", "beta3mu",
              "sigma", "zsigma", "nu",
              "beta0[1]" , "beta1[1]",  "beta2[1]", "beta3[1]",
              "zbeta0[1]" , "zbeta1[1]", "zbeta2[1]", "zbeta3[1]")

foreach (p=1:length(parToPlot)) %dopar% {
    parName = parToPlot[p]
    pdf(file=paste0(resDir, "MCMC_diagnostics/overall_", parName, ".pdf"), width=7, height=5)
    diagMCMC(codaObject=mcmcCodaOverall, parName=parName) 
    dev.off()
}

summDFOverall = summarizePostListDF(list(mcmcMatOverall[, "beta0mu"], mcmcMatOverall[, "beta1mu"], mcmcMatOverall[, "beta2mu"], mcmcMatOverall[, "beta3mu"]), labels=c("Intercept", "slopeF1", "slopeF2", "slopeF3"))

summDFSlopeDiffOverall = summarizePostListDF(list(
    mcmcMatOverall[, "beta1mu"]-mcmcMatOverall[, "beta2mu"],
    mcmcMatOverall[, "beta1mu"]-mcmcMatOverall[, "beta3mu"],
    mcmcMatOverall[, "beta2mu"]-mcmcMatOverall[, "beta3mu"]),
    labels=c("Slope 1 - Slope 2", "Slope 1 - Slope 3", "Slope 2 - Slope 3"))

summDFOverallZ = summarizePostListDF(list(mcmcMatOverall[, "zbeta0mu"], mcmcMatOverall[, "zbeta1mu"], mcmcMatOverall[, "zbeta2mu"], mcmcMatOverall[, "zbeta3mu"]), labels=c("Intercept", "slopeF1", "slopeF2", "slopeF3"))

summDFSlopeDiffOverallZ = summarizePostListDF(list(
    mcmcMatOverall[, "zbeta1mu"]-mcmcMatOverall[, "zbeta2mu"],
    mcmcMatOverall[, "zbeta1mu"]-mcmcMatOverall[, "zbeta3mu"],
    mcmcMatOverall[, "zbeta2mu"]-mcmcMatOverall[, "zbeta3mu"]),
    labels=c("Slope 1 - Slope 2", "Slope 1 - Slope 3", "Slope 2 - Slope 3"))

write.table(summDFOverall, paste0(resDir, "figures_data/summDF_overall.csv"), col.names=T, row.names=F)
write.table(summDFSlopeDiffOverall, paste0(resDir, "figures_data/summDF_slope_diff_overall.csv"), col.names=T, row.names=F)
write.table(summDFOverallZ, paste0(resDir, "figures_data/summDF_overall_z.csv"), col.names=T, row.names=F)
write.table(summDFSlopeDiffOverallZ, paste0(resDir, "figures_data/summDF_slope_diff_overall_z.csv"), col.names=T, row.names=F)

pdf(paste0(resDir, "overall_posterior_z.pdf"))
par(mfrow=c(2,2))
plotPost(mcmcMatOverall[, "zbeta0mu"], main="St. Intercept")
plotPost(mcmcMatOverall[, "zbeta1mu"], main="St. Slope Factor 1")
plotPost(mcmcMatOverall[, "zbeta2mu"], main="St. Slope Factor 2")
plotPost(mcmcMatOverall[, "zbeta3mu"], main="St. Slope factor 3")
dev.off()

pdf(paste0(resDir, "overall_posterior.pdf"))
par(mfrow=c(2,2))
plotPost(mcmcMatOverall[, "beta0mu"], main="Intercept")
plotPost(mcmcMatOverall[, "beta1mu"], main="Slope Factor 1")
plotPost(mcmcMatOverall[, "beta2mu"], main="Slope Factor 2")
plotPost(mcmcMatOverall[, "beta3mu"], main="Slope Factor 3")
dev.off()

pdf(paste0(resDir, "overall_posterior_slope_diff.pdf"))
par(mfrow=c(2,2))
plotPost(mcmcMatOverall[, "beta1mu"]-mcmcMatOverall[, "beta2mu"], main="Slope 1 - Slope 2")
plotPost(mcmcMatOverall[, "beta1mu"]-mcmcMatOverall[, "beta3mu"], main="Slope 1 - Slope 3")
plotPost(mcmcMatOverall[, "beta2mu"]-mcmcMatOverall[, "beta3mu"], main="Slope 2 - Slope 3")
dev.off()

pdf(paste0(resDir, "overall_posterior_slope_diff_z.pdf"))
par(mfrow=c(2,2))
plotPost(mcmcMatOverall[, "zbeta1mu"]-mcmcMatOverall[, "zbeta2mu"], main="St. Slope 1 - St. Slope 2")
plotPost(mcmcMatOverall[, "zbeta1mu"]-mcmcMatOverall[, "zbeta3mu"], main="St. Slope 1 - St. Slope 3")
plotPost(mcmcMatOverall[, "zbeta2mu"]-mcmcMatOverall[, "zbeta3mu"], main="St. Slope 2 - St. Slope 3")
dev.off()

## ##################################################
## Multiple regression: playability ~ factor scores
## ##################################################

if (updateMCMCSampling == TRUE | file.exists(paste0(resDir, "MCMC_playability.RDS")) == FALSE){
    mcmcCodaPlayability = genMCMCYMetXMetThreeMRobustSubj(data=dat, xName=c("F1","F2", "F3"), yName="playability", 
        numSavedSteps=numSavedStepsRegMulti, thinSteps=thinStepsRegMulti)
    saveRDS(mcmcCodaPlayability, file=paste0(resDir, "MCMC_playability.RDS"), compress="xz")
} else {
    mcmcCodaPlayability = readRDS(paste0(resDir, "MCMC_playability.RDS"))
}

mcmcMatPlayability = as.matrix(mcmcCodaPlayability, chains=T)

parToPlot = c("zbeta0mu", "zbeta1mu", "zbeta2mu", "zbeta3mu",
              "beta0mu", "beta1mu",  "beta2mu", "beta3mu",
              "sigma", "zsigma", "nu",
              "beta0[1]" , "beta1[1]",  "beta2[1]", "beta3[1]",
              "zbeta0[1]" , "zbeta1[1]", "zbeta2[1]", "zbeta3[1]")

foreach (p=1:length(parToPlot)) %dopar% {
    parName = parToPlot[p]
    pdf(file=paste0(resDir, "MCMC_diagnostics/playability_", parName, ".pdf"), width=7, height=5)
    diagMCMC(codaObject=mcmcCodaPlayability, parName=parName) 
    dev.off()
}

summDFPlayability = summarizePostListDF(list(mcmcMatPlayability[, "beta0mu"], mcmcMatPlayability[, "beta1mu"], mcmcMatPlayability[, "beta2mu"], mcmcMatPlayability[, "beta3mu"]), labels=c("Intercept", "slopeF1", "slopeF2", "slopeF3"))

summDFSlopeDiffPlayability = summarizePostListDF(list(
    mcmcMatPlayability[, "beta1mu"]-mcmcMatPlayability[, "beta2mu"],
    mcmcMatPlayability[, "beta1mu"]-mcmcMatPlayability[, "beta3mu"],
    mcmcMatPlayability[, "beta2mu"]-mcmcMatPlayability[, "beta3mu"]),
    labels=c("Slope 1 - Slope 2", "Slope 1 - Slope 3", "Slope 2 - Slope 3"))

summDFPlayabilityZ = summarizePostListDF(list(mcmcMatPlayability[, "zbeta0mu"], mcmcMatPlayability[, "zbeta1mu"], mcmcMatPlayability[, "zbeta2mu"], mcmcMatPlayability[, "zbeta3mu"]), labels=c("Intercept", "slopeF1", "slopeF2", "slopeF3"))

summDFSlopeDiffPlayabilityZ = summarizePostListDF(list(
    mcmcMatPlayability[, "zbeta1mu"]-mcmcMatPlayability[, "zbeta2mu"],
    mcmcMatPlayability[, "zbeta1mu"]-mcmcMatPlayability[, "zbeta3mu"],
    mcmcMatPlayability[, "zbeta2mu"]-mcmcMatPlayability[, "zbeta3mu"]),
    labels=c("Slope 1 - Slope 2", "Slope 1 - Slope 3", "Slope 2 - Slope 3"))

write.table(summDFPlayability, paste0(resDir, "figures_data/summDF_playability.csv"), col.names=T, row.names=F)
write.table(summDFSlopeDiffPlayability, paste0(resDir, "figures_data/summDF_slope_diff_playability.csv"), col.names=T, row.names=F)
write.table(summDFPlayabilityZ, paste0(resDir, "figures_data/summDF_playability_z.csv"), col.names=T, row.names=F)
write.table(summDFSlopeDiffPlayabilityZ, paste0(resDir, "figures_data/summDF_slope_diff_playability_z.csv"), col.names=T, row.names=F)

pdf(paste0(resDir, "playability_posterior_z.pdf"))
par(mfrow=c(2,2))
plotPost(mcmcMatPlayability[, "zbeta0mu"], main="St. Intercept")
plotPost(mcmcMatPlayability[, "zbeta1mu"], main="St. Slope Factor 1")
plotPost(mcmcMatPlayability[, "zbeta2mu"], main="St. Slope Factor 2")
plotPost(mcmcMatPlayability[, "zbeta3mu"], main="St. Slope factor 3")
dev.off()

pdf(paste0(resDir, "playability_posterior.pdf"))
par(mfrow=c(2,2))
plotPost(mcmcMatPlayability[, "beta0mu"], main="Intercept")
plotPost(mcmcMatPlayability[, "beta1mu"], main="Slope Factor 1")
plotPost(mcmcMatPlayability[, "beta2mu"], main="Slope Factor 2")
plotPost(mcmcMatPlayability[, "beta3mu"], main="Slope Factor 3")
dev.off()

pdf(paste0(resDir, "playability_posterior_slope_diff.pdf"))
par(mfrow=c(2,2))
plotPost(mcmcMatPlayability[, "beta1mu"]-mcmcMatPlayability[, "beta2mu"], main="Slope 1 - Slope 2")
plotPost(mcmcMatPlayability[, "beta1mu"]-mcmcMatPlayability[, "beta3mu"], main="Slope 1 - Slope 3")
plotPost(mcmcMatPlayability[, "beta2mu"]-mcmcMatPlayability[, "beta3mu"], main="Slope 2 - Slope 3")
dev.off()


pdf(paste0(resDir, "playability_posterior_slope_diff_z.pdf"))
par(mfrow=c(2,2))
plotPost(mcmcMatPlayability[, "zbeta1mu"]-mcmcMatPlayability[, "zbeta2mu"], main="St. Slope 1 - St. Slope 2")
plotPost(mcmcMatPlayability[, "zbeta1mu"]-mcmcMatPlayability[, "zbeta3mu"], main="St. Slope 1 - St. Slope 3")
plotPost(mcmcMatPlayability[, "zbeta2mu"]-mcmcMatPlayability[, "zbeta3mu"], main="St. Slope 2 - St. Slope 3")
dev.off()

t2 = Sys.time()
print(t2-t1)
