source("global_parameters.R")
source("utils.R")

dat = read.table("../datasets/ABX_synth.csv", header=T)

ABXParticipants = unique(as.character(dat$listener))
ABXGuitarPairs = unique(as.character(dat$condition))

datABX = data.frame()
for (i in 1:length(ABXParticipants)){
    thisPart = ABXParticipants[i]
    for (j in 1:length(ABXGuitarPairs)){
        thisGuitarPair = ABXGuitarPairs[j]
        thisInputDF = dat[dat$listener == thisPart & dat$condition==thisGuitarPair,]

        thisInputDF$A = as.character(thisInputDF$A)
        thisInputDF$B = as.character(thisInputDF$B)
        thisInputDF$X = as.character(thisInputDF$X)
        nTotA = length(thisInputDF[thisInputDF$A == thisInputDF$X, 'X'])
        nTotB = length(thisInputDF[thisInputDF$B == thisInputDF$X, 'X'])
        nCorrA = sum(thisInputDF[thisInputDF$A == thisInputDF$X, 'response'])
        nCorrB = sum(thisInputDF[thisInputDF$B == thisInputDF$X, 'response'])
        nIncorrA = nTotA - nCorrA
        nIncorrB = nTotB - nCorrB
        nCorr = sum(thisInputDF$response)
        nTot = length(thisInputDF$response)
        thisOutputDF = data.frame(listener=thisPart, condition=thisGuitarPair, type=thisInputDF$type[1], yearsExp=thisInputDF$yearsExp[1], nCorrA=nCorrA, nIncorrA=nIncorrA, nTotA=nTotA, nCorrB=nCorrB, nIncorrB=nIncorrB, nTotB=nTotB)
        datABX = rbind(datABX, thisOutputDF)
    }
}

datABX$HR = datABX$nCorrA/datABX$nTotA
datABX$FA = datABX$nIncorrB/datABX$nTotB

datABX$dprime = numeric(length(datABX$listener))
for (i in 1:length(datABX$listener)){
    datABX$dprime[i] = dp_ABX_2N(datABX$nCorrA[i], datABX$nTotA[i], datABX$nIncorrB[i], datABX$nTotB[i], method="IO")
}
datABX$conditionLabels = factor(datABX$condition,
    levels=c("Braz_Rsw_vs_Sapele", "Braz_Rsw_vs_Walnut", "Sapele_vs_Walnut", "Ind_Rsw_vs_Sapele", "Ind_Rsw_vs_Yamaha"),
    labels=c("Braz. Rsw. vs Sapele", "Braz. Rsw. vs Walnut", "Sapele vs Walnut", "Ind. Rsw. vs Sapele",  "Ind. Rsw. vs Yamaha"))
write.table(datABX, "../derived_datasets/ABX_synth_dprime.csv", col.names=T, row.names=F) 
