t1 = Sys.time()
library(psych)
currDir = getwd()
setwd("../")
source("global_parameters.R")
setwd(currDir)
resDir = "../../results/factor_analysis/"
dir.create(resDir, recursive=T, showWarnings=F)

## load data
dat = read.table("../../datasets/blinded_ratings.csv", header=T)
dat_unblinded = read.table("../../datasets/unblinded_ratings.csv", header=T)
datS1 = dat[dat$rep == "first",]
datS2 = dat[dat$rep == "second",]

scales = names(dat)
scales = scales[-c(which(scales == "subject"), which(scales=="guitar"), which(scales=="type"), which(scales=="yearsExp"), which(scales == "rep"))]
## ############################################
## Factor analysis on pooled correlation matrix
## ############################################

cBraz = cor(datS1[datS1$guitar=="braz", scales[-c(which(scales== "overall"), which(scales== "playability"))]])
cInd = cor(datS1[datS1$guitar=="indi", scales[-c(which(scales== "overall"), which(scales== "playability"))]])
cWaln = cor(datS1[datS1$guitar=="waln", scales[-c(which(scales== "overall"), which(scales== "playability"))]])
cSape = cor(datS1[datS1$guitar=="sape", scales[-c(which(scales== "overall"), which(scales== "playability"))]])
cMaho = cor(datS1[datS1$guitar=="maho", scales[-c(which(scales== "overall"), which(scales== "playability"))]])
cMapl = cor(datS1[datS1$guitar=="mapl", scales[-c(which(scales== "overall"), which(scales== "playability"))]])

cBrazr2 = cor(datS2[datS2$guitar=="braz", scales[-c(which(scales== "overall"), which(scales== "playability"))]])
cIndr2 = cor(datS2[datS2$guitar=="indi", scales[-c(which(scales== "overall"), which(scales== "playability"))]])
cWalnr2 = cor(datS2[datS2$guitar=="waln", scales[-c(which(scales== "overall"), which(scales== "playability"))]])
cSaper2 = cor(datS2[datS2$guitar=="sape", scales[-c(which(scales== "overall"), which(scales== "playability"))]])
cMahor2 = cor(datS2[datS2$guitar=="maho", scales[-c(which(scales== "overall"), which(scales== "playability"))]])
cMaplr2 = cor(datS2[datS2$guitar=="mapl", scales[-c(which(scales== "overall"), which(scales== "playability"))]])

pooledCorrMatr1 = fisherz2r((fisherz(cInd) + fisherz(cBraz) + fisherz(cSape) + fisherz(cMaho)+ fisherz(cMapl) + fisherz(cWaln) )/6)
pooledCorrMatr2 = fisherz2r((fisherz(cIndr2) + fisherz(cBrazr2) + fisherz(cSaper2) + fisherz(cMahor2)+ fisherz(cMaplr2) + fisherz(cWalnr2))/6)
pooledCorrMatr = fisherz2r((fisherz(pooledCorrMatr1)*52/86+fisherz(pooledCorrMatr2)*34/86))

pooledCorrMatr[is.nan(pooledCorrMatr)] = 1

faPCPooled = fa(r=pooledCorrMatr, nfactors=3, rotate="varimax", fm="ml", scores="Anderson")
colnames(faPCPooled$loadings) = paste("F", 1:length(colnames(faPCPooled$loadings)), sep="")
faScores = factor.scores(dat[, scales[-c(which(scales== "overall"), which(scales== "playability"))]], faPCPooled, method="Anderson")
#factor.plot(faPC, cut=0.5)
pdf(paste0(resDir, "fa_diagram_pooled.pdf"))
fa.diagram(faPCPooled)
dev.off()


## ############################################
## Pooled correlation matrix dropped variables
## ############################################

varsToDrop =  c(which(scales== "overall"), which(scales== "playability"),
    which(scales== "balance"),
    which(scales== "complexity"),
    which(scales== "separation"),
    ## which(scales== "projection"),
    ## which(scales== "big"),
    ## which(scales== "headroom"),
    which(scales== "sustain"))
#    which(scales== "richness"),

cBrazDrpd = cor(datS1[datS1$guitar=="braz", scales[-varsToDrop]])
cIndDrpd = cor(datS1[datS1$guitar=="indi", scales[-varsToDrop]])
cWalnDrpd = cor(datS1[datS1$guitar=="waln", scales[-varsToDrop]])
cSapeDrpd = cor(datS1[datS1$guitar=="sape", scales[-varsToDrop]])
cMahoDrpd = cor(datS1[datS1$guitar=="maho", scales[-varsToDrop]])
cMaplDrpd = cor(datS1[datS1$guitar=="mapl", scales[-varsToDrop]])

cBrazDrpdr2 = cor(datS2[datS2$guitar=="braz", scales[-varsToDrop]])
cIndDrpdr2 = cor(datS2[datS2$guitar=="indi", scales[-varsToDrop]])
cWalnDrpdr2 = cor(datS2[datS2$guitar=="waln", scales[-varsToDrop]])
cSapeDrpdr2 = cor(datS2[datS2$guitar=="sape", scales[-varsToDrop]])
cMahoDrpdr2 = cor(datS2[datS2$guitar=="maho", scales[-varsToDrop]])
cMaplDrpdr2 = cor(datS2[datS2$guitar=="mapl", scales[-varsToDrop]])

pooledCorrMatrDrpd1 = fisherz2r((fisherz(cIndDrpd) + fisherz(cBrazDrpd) + fisherz(cSapeDrpd) + fisherz(cMahoDrpd)+ fisherz(cMaplDrpd) + fisherz(cWalnDrpd) )/6)
pooledCorrMatrDrpd2 = fisherz2r((fisherz(cIndDrpdr2) + fisherz(cBrazDrpdr2) + fisherz(cSapeDrpdr2) + fisherz(cMahoDrpdr2)+ fisherz(cMaplDrpdr2) + fisherz(cWalnDrpdr2))/6)
pooledCorrMatrDrpd = fisherz2r((fisherz(pooledCorrMatrDrpd1)*52/86+fisherz(pooledCorrMatrDrpd2)*34/86))

pooledCorrMatrDrpd[is.nan(pooledCorrMatrDrpd)] = 1

faPCPooledDrpd = fa(r=pooledCorrMatrDrpd, nfactors=3, rotate="varimax", fm="ml", scores="Anderson")
colnames(faPCPooledDrpd$loadings) = paste("F", 1:length(colnames(faPCPooledDrpd$loadings)), sep="") ##c("F2", "F1", "F3")#
faScoresDrpd = factor.scores(dat[, scales[-varsToDrop]], faPCPooledDrpd, method="Anderson")
faScoresUnblindedDrpd = factor.scores(dat_unblinded[, scales[-varsToDrop]], faPCPooledDrpd, method="Anderson")

pdf(paste0(resDir, "fa_diagram_pooled_dropped_vars.pdf"))
fa.diagram(faPCPooledDrpd)
dev.off()
fa.graph(faPCPooledDrpd, out.file=paste0(resDir, "fa_diagram_pooled_dropped_vars.gv"))

dat = cbind(dat, faScoresDrpd$scores)
dat_unblinded = cbind(dat_unblinded, faScoresUnblindedDrpd$scores)
write.table(dat, file="../../derived_datasets/blinded_ratings_with_EFA_scores.csv", col.names=T, row.names=F)
write.table(dat_unblinded, file="../../derived_datasets/unblinded_ratings_with_EFA_scores.csv", col.names=T, row.names=F)


