library(ggplot2)
library(dplyr)
library(cowplot)
library(gtools)
library(scales)
library(RColorBrewer)
source("global_parameters.R")
source("utils.R")

resDir = "../results/paper_plots/"

clsAllListenersSynth = adjustcolor(brewer.pal(8, "Dark2"), alpha.f=1)

dir.create(resDir, recursive=T, showWarnings=F)

## ###############################
## Overall & Playability HDIs
## ###############################
datSummOverall = read.table("../results/blinded_overall/figures_data/df_within_contrasts.csv", header=T)
datSummOverall$scale = "Overall"
datSummPlayability = read.table("../results/blinded_playability/figures_data/df_within_contrasts.csv", header=T)
datSummPlayability$scale = "Playability"

datSummOverallPlayability = rbind(datSummOverall, datSummPlayability)

dodgeSize = -0.75
p = ggplot(datSummOverallPlayability, aes(x=labelNice, y=Mode, shape=scale, color=scale))
p = p + geom_hline(yintercept=0, linetype=3)
p = p + geom_hline(yintercept=c(-0.2, 0.2), linetype=3, color="gray60")
p = p + coord_flip()
p = p + geom_point(position=position_dodge(dodgeSize))
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0, position=position_dodge(dodgeSize))
p = p + scale_y_continuous(limits=c(-1,1))
p = p + scale_shape_discrete(name=NULL)
p = p + scale_color_manual(name=NULL, values=twoCol)
p = p + theme_bw2 + theme(legend.position=c(0.4, 1.065),
    legend.direction="horizontal",
    plot.margin=unit(c(1.65,0.2,0.2,0.2),"lines"))
p = p + ylab("Rating Difference") + theme(axis.title.x = element_text(hjust=0.5)) + xlab(NULL)
p_HDIs_contrasts_within = p
ggsave(filename=paste0(resDir, "Fig4_HDIs_contrasts_within.pdf"), p_HDIs_contrasts_within, width=size1c, height=3.8)
#ggsave(filename=paste0(resDir, "Fig4.pdf"), p_HDIs_contrasts_within, width=size1c, height=3.8)

dodgeSize = -0.75
p = ggplot(datSummOverallPlayability, aes(x=labelNice, y=Mode, shape=scale, color=scale))
p = p + geom_hline(yintercept=0, linetype=3)
p = p + geom_hline(yintercept=c(-0.2, 0.2), linetype=3, color="gray60")
p = p + geom_point(position=position_dodge(dodgeSize))
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0, position=position_dodge(dodgeSize))
p = p + scale_y_continuous(limits=c(-1,1))
p = p + scale_shape_discrete(name=NULL)
p = p + scale_color_manual(name=NULL, values=twoCol)
p = p + theme_bw2
p = p + coord_flip()
p = p + ylab("Rating Difference") + theme(axis.title.x = element_text(hjust=0.5)) + xlab(NULL)


## #############################################
## Overall playability barplot horizontal
## #############################################
datRatings = read.table("../datasets/blinded_ratings.csv", header=T)
datRatingsSubjSummOverall = datRatings %>% group_by(subject, guitar) %>% summarize(s_mean=mean(overall))
datRatingsSubjSummPlayability = datRatings %>% group_by(subject, guitar) %>% summarize(s_mean=mean(playability))
datRatingsSummOverall = datRatingsSubjSummOverall %>% group_by(guitar) %>% summarize(mean=mean(s_mean), se=se(s_mean))
datRatingsSummOverall$scale = "Overall"
datRatingsSummPlayability = datRatingsSubjSummPlayability %>% group_by(guitar) %>% summarize(mean=mean(s_mean), se=se(s_mean))
datRatingsSummPlayability$scale = "Playability"

datRatingsSummOverallPlayability = rbind(datRatingsSummOverall, datRatingsSummPlayability)
datRatingsSummOverallPlayability$guitarLabel = gsub2(guitarCodes, guitarLabelsShort, datRatingsSummOverallPlayability$guitar)

dodgeSize = -0.9
p = ggplot(datRatingsSummOverallPlayability, aes(x=guitarLabel, y=mean, fill=scale))
p = p + geom_bar(stat="identity", position=position_dodge(dodgeSize))
p = p + geom_errorbar(aes(ymin=mean-se, ymax=mean+se), position=position_dodge(dodgeSize), width=0.5)
p = p + scale_fill_manual(name=NULL, values=twoCol)
p = p + coord_flip() + theme_bw2
p = p + theme(legend.position=c(0.3, 1.065),
    legend.direction="horizontal",
    plot.margin=unit(c(1.65,0.2,0.2,0.2),"lines"))
p = p + ylab("Rating") + xlab(NULL)
p_barplot_overall_playability_h = p
ggsave(filename=paste0(resDir, "barplot_overall_playability_horizontal.pdf"), p_barplot_overall_playability_h, width=size1c, height=3.8)

## #############################################
## Overall playability barplot vertical
## #############################################

trans_barplot_origin = function(from=0){
    trans = function(x) x-from
    inv = function(x) x+from
    trans_new("myscale", trans, inv,
              domain = c(from, Inf))
}

dodgeSize = 0.9
p = ggplot(datRatingsSummOverallPlayability, aes(x=guitarLabel, y=mean, fill=scale))
p = p + geom_bar(stat="identity", position=position_dodge(dodgeSize))
p = p + geom_errorbar(aes(ymin=mean-se, ymax=mean+se), position=position_dodge(dodgeSize), width=0.5)
p = p + scale_fill_manual(name=NULL, values=twoCol)
p = p + scale_y_continuous(limits=c(1, 5), trans = trans_barplot_origin(from=1))
##p = p + coord_cartesian(ylim=c(1,5))
p = p + theme_bw2 + theme(axis.text.x = element_text(angle=45, hjust=1))
p = p + theme(legend.position="top")
p = p + ylab("Rating") + xlab(NULL)
p_barplot_overall_playability_v = p
ggsave(filename=paste0(resDir, "Fig3_barplot_overall_playability_vertical.pdf"), p_barplot_overall_playability_v, width=size1c, height=size1c)
#ggsave(filename=paste0(resDir, "Fig3.pdf"), p_barplot_overall_playability_v, width=size1c, height=size1c)

## ###############################################
## Overall playability barplot and HDIs combined
## ###############################################
p = plot_grid(p_barplot_overall_playability_h, p_HDIs_contrasts_within, labels = c("A", "B"), align="h", rel_widths=c(1.5,2))
save_plot(paste0(resDir, "barplot_HDIs_overall_playability.pdf"), p,
          ncol = 2,
          nrow = 1,
          base_width=size2c/2,
          base_height=4)

withinContrastsDFOverallByType = read.table("../results/blinded_overall/figures_data/df_within_contrasts_by_type.csv", header=T)
withinContrastsDFOverallByType$scale = "Overall"
withinContrastsDFOverallByType$figLbl = "A"
withinContrastsDFOverallByType$figxlab = "Overall Rating Difference"
dodgeSize = -0.75
p = ggplot(withinContrastsDFOverallByType, aes(x=labelNice, y=Mode, shape=typeLabel, color=typeLabel)) + geom_point(position=position_dodge(dodgeSize))
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0, position=position_dodge(dodgeSize))
p = p + geom_hline(yintercept=0, linetype=3) + coord_flip()
p = p + geom_hline(yintercept=c(-0.2, 0.2), linetype=3, color="gray60")
p = p + scale_y_continuous(limits=c(-1,1))
p = p + theme_bw2 + theme(legend.position=c(0.2, 1.07),
    legend.direction="horizontal",
    plot.margin=unit(c(1.5,0.2,0.2,0.2),"lines"))
p = p + ylab("Overall Sound Rating Difference") + theme(axis.title.x = element_text(hjust=1)) + xlab(NULL)
p = p + scale_shape_discrete(name=NULL)
p = p + scale_color_manual(name=NULL, values=pTypeCol)
HDIs_contrasts_within_overall_by_type = p
ggsave(filename=paste0(resDir, "HDIs_contrasts_within_overall_by_type.pdf"), p, width=size1c, height=3.8)

withinContrastsDFPlayabilityByType = read.table("../results/blinded_playability/figures_data/df_within_contrasts_by_type.csv", header=T)
withinContrastsDFPlayabilityByType$scale = "Playability"
withinContrastsDFPlayabilityByType$figLbl = "B"
withinContrastsDFPlayabilityByType$figxlab = "Playability Rating Difference"
dodgeSize = -0.75
p = ggplot(withinContrastsDFPlayabilityByType, aes(x=labelNice, y=Mode, shape=typeLabel, color=typeLabel)) + geom_point(position=position_dodge(dodgeSize))
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0, position=position_dodge(dodgeSize))
p = p + geom_hline(yintercept=0, linetype=3) + coord_flip()
p = p + geom_hline(yintercept=c(-0.2, 0.2), linetype=3, color="gray60")
p = p + scale_y_continuous(limits=c(-1,1))
p = p + theme_bw2 + theme(legend.position=c(0.2, 1.07),
    legend.direction="horizontal",
    plot.margin=unit(c(1.5,0.2,0.2,0.2),"lines"))
p = p + ylab("Playability Rating Difference") + theme(axis.title.x = element_text(hjust=1)) + xlab(NULL)
p = p + scale_shape_discrete(name=NULL)
p = p + scale_color_manual(name=NULL, values=pTypeCol)
HDIs_contrasts_within_playability_by_type = p
ggsave(filename=paste0(resDir, "HDIs_contrasts_within_playability_by_type.pdf"), p, width=size1c, height=3.8)

withinContrastsDFOverallPlayabilityByType = rbind(withinContrastsDFOverallByType, withinContrastsDFPlayabilityByType)
withinContrastsDFOverallPlayabilityByType$typeLabel = factor(withinContrastsDFOverallPlayabilityByType$typeLabel, levels=c("Professional", "Semi-pro", "Amateur"))
p = ggplot(withinContrastsDFOverallPlayabilityByType, aes(x=labelNice, y=Mode, shape=typeLabel, color=typeLabel)) + geom_point(position=position_dodge(dodgeSize)) + facet_wrap(~figLbl)
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0, position=position_dodge(dodgeSize))
p = p + geom_hline(yintercept=0, linetype=3) + coord_flip()
p = p + geom_hline(yintercept=c(-0.2, 0.2), linetype=3, color="gray60")
p = p + scale_y_continuous(limits=c(-1,1))
p = p + theme_bw2 + theme(legend.position=c(0.25, 1.07),
    legend.direction="horizontal")
#    plot.margin=unit(c(1.2,0.2,0.2,0.2),"lines"))
p = p + theme(strip.background = element_blank(), strip.text = element_text(hjust = 0), strip.text.x = element_text(face="bold", size=16, margin = margin(0,0,1.1,0, "cm")))
#p = p + geom_text(aes(label=figxlab), x=0.5, y=-0.5)
p = p + xlab(NULL) + ylab("  Overall Sound Rating Difference            Playability Rating Difference")
p = p + scale_shape_discrete(name=NULL)
p = p + scale_color_manual(name=NULL, values=pTypeCol)
ggsave(filename=paste0(resDir, "SI_Fig1_overall_playability_rating_CIs_by_type.pdf"), p, width=size2c, height=4.2)
## ####################################
## Factor scores
## ####################################

postDatF1 = read.table("../results/blinded_factor_scores_F1/figures_data/df_within_contrasts.csv", header=T)
postDatF1$factor = "F1"

postDatF2 = read.table("../results/blinded_factor_scores_F2/figures_data/df_within_contrasts.csv", header=T)
postDatF2$factor = "F2"

postDatF3 = read.table("../results/blinded_factor_scores_F3/figures_data/df_within_contrasts.csv", header=T)
postDatF3$factor = "F3"
postDatFAScores = rbind(postDatF1, postDatF2, postDatF3)


dodgeSize = -0.75
p = ggplot(postDatFAScores, aes(x=labelNice, y=Mode, shape=factor, color=factor))
p = p + geom_hline(yintercept=0, linetype=3) + coord_flip()
p = p + geom_hline(yintercept=c(-0.2, 0.2), linetype=3, color="gray60")
p = p + geom_point(position=position_dodge(dodgeSize))
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0, position=position_dodge(dodgeSize))
p = p + scale_y_continuous(limits=c(-1,1))
p = p + scale_shape_discrete(name=NULL)
p = p + scale_color_manual(name=NULL, values=factorsCol)
p = p + theme_bw2 + theme(legend.position=c(0.4, 1.065),
    legend.direction="horizontal",
    plot.margin=unit(c(1.65,0.2,0.2,0.2),"lines"))
p = p + ylab("Factor Score Difference") + theme(axis.title.x = element_text(hjust=0.5)) + xlab(NULL)
p_HDIs_contrasts_within_factor_scores = p
#ggsave(filename=paste0(resDir, "HDIs_contrasts_within_factor_scores.pdf"), p_HDIs_contrasts_within_factor_scores, width=size1c, height=3.8)
ggsave(filename=paste0(resDir, "SI_Fig4_factor_score_differences_CIs.pdf"), p_HDIs_contrasts_within_factor_scores, width=size1c, height=3.8)

## ################################
## Barplot factor scores horizontal
## ################################
datFAScores = read.table("../derived_datasets/blinded_ratings_with_EFA_scores.csv", header=T)
datFAScoresStacked = data.frame(datFAScores[1:5], stack(datFAScores, select=c("F1", "F2", "F3")))
datFAScoresSummSubj = datFAScoresStacked %>% group_by(subject, guitar, ind) %>% summarize(meanSubjScore=mean(values))
datFAScoresSumm = datFAScoresSummSubj %>% group_by(guitar, ind) %>% summarize(meanScore=mean(meanSubjScore), seScore=se(meanSubjScore))
datFAScoresSumm$guitarLabel = gsub2(guitarCodes, guitarLabelsShort, datFAScoresSumm$guitar)

dodgeSize = -0.9
p = ggplot(datFAScoresSumm, aes(x=guitarLabel, y=meanScore, fill=ind))
p = p + geom_bar(stat="identity", position=position_dodge(dodgeSize))
p = p + geom_errorbar(aes(ymin=meanScore-seScore, ymax=meanScore+seScore), position=position_dodge(dodgeSize), width=0.5)
p = p + scale_fill_manual(name=NULL, values=factorsCol)
p = p + coord_flip() + theme_bw2
p = p + theme(legend.position=c(0.3, 1.065),
    legend.direction="horizontal",
    plot.margin=unit(c(1.65,0.2,0.2,0.2),"lines"))
p = p + scale_y_continuous(limits=c(-1,1))
p = p + ylab("Factor Score") + xlab(NULL)
p_barplot_factor_scores_h = p
ggsave(filename=paste0(resDir, "barplot_factor_scores_horizontal.pdf"), p_barplot_factor_scores_h, width=size1c, height=3.8)

## ################################
## Barplot factor scores vertical
## ################################
dodgeSize = 0.9
p = ggplot(datFAScoresSumm, aes(x=guitarLabel, y=meanScore, fill=ind))
p = p + geom_bar(stat="identity", position=position_dodge(dodgeSize))
p = p + geom_errorbar(aes(ymin=meanScore-seScore, ymax=meanScore+seScore), position=position_dodge(dodgeSize), width=0.5)
p = p + scale_fill_manual(name=NULL, values=factorsCol)
p = p + theme_bw2 + theme(axis.text.x = element_text(angle=45,hjust=1))
p = p + theme(legend.position="top")
p = p + scale_y_continuous(limits=c(-0.5,0.5))
p = p + ylab("Factor Score") + xlab(NULL)
p_barplot_factor_scores_v = p
ggsave(filename=paste0(resDir, "barplot_factor_scores_vertical.pdf"), p_barplot_factor_scores_v, width=size1c, height=3.8)

## ########################################
## Barplot and HDIs combined factor scores
## ########################################
p = plot_grid(p_barplot_factor_scores_h, p_HDIs_contrasts_within_factor_scores, labels = c("A", "B"), align="h", rel_widths=c(1.5,2))
save_plot(paste0(resDir, "barplot_HDIs_factor_scores.pdf"), p,
          ncol = 2,
          nrow = 1,
          base_width=size2c/2,
          base_height=4)


## ##############################
## Correlation Rep1 Rep2
## ##############################

datRep12 = read.table("../derived_datasets/blinded_ratings_rep1_rep2.csv", header=T)
datRep12$subject = factor(datRep12$subject, levels=mixedsort(levels(datRep12$subject)))
df_cor12_lims_overall = read.table("../results/blinded_correlation_rep1_rep2/figures_data/df_cor12_lims2_overall.csv", header=T)
df_cor12_coeffs_overall = read.table("../results/blinded_correlation_rep1_rep2/figures_data/df_cor12_coeffs_overall.csv", header=T)

## ggplot2
p = ggplot(datRep12, aes(overallZ, overallZ2)) + geom_point() + facet_wrap(~subject) + coord_fixed()
p = p + geom_polygon(data=df_cor12_lims_overall, aes(x=x, y=y), fill=add.alpha("gray", alpha=0.5))
p = p + geom_abline(data=df_cor12_coeffs_overall, aes(intercept=interceptMCMC, slope=slopeMCMC), color="indianred")
p = p + geom_abline(data=df_cor12_coeffs_overall, aes(slope=slopeLinear, intercept=interceptLinear), color="skyblue", linetype=1)
p = p + xlab(expression(paste("Overall Sound Rating Sess. #1 (", italic("z"), " Score)")))
p = p + ylab(expression(paste("Overall Sound Rating Sess. #2 (", italic("z"), " Score)")))
p = p + theme_bw2 + theme(panel.spacing = unit(0, "lines"), strip.background = element_blank(),
    strip.text.x = element_blank())
p = p + scale_x_continuous(breaks=c(-1.5, 0, 1.5), limits=c(-2.21,2.21))
p = p + scale_y_continuous(breaks=c(-1.5, 0, 1.5), limits=c(-2.21,2.21))
p = p + geom_text(x=1.65, y=1.75, aes(label=subject))
ggsave(filename=paste0(resDir, "cor_r1_r2.pdf"), p, width=size2c, height=size2c)

## R Base graphics
subjs = mixedsort(levels(datRep12$subject))
theseLims = c(-2.21, 2.21)
pdf(paste0(resDir, "SI_Fig2_overall_cor_r1_r2.pdf"), width=6.8, height=6.8)
par(mfrow=c(6,6), mar=c(0,0,0,0), oma=c(4,4.1,1,0.9), ps = 12, cex = 1, cex.main = 1)
for (sn in 1:length(subjs)){
    thisSubj = subjs[sn]
    plot.new(); plot.window(xlim=theseLims, ylim=theseLims)
    theseCILims = df_cor12_lims_overall %>% filter(subject==thisSubj)
    theseCoeffs = df_cor12_coeffs_overall %>% filter(subject==thisSubj)

    polygon(theseCILims$x, theseCILims$y, col=add.alpha("gray", alpha=0.5), border=NA)
    g = lm(datRep12[datRep12$subject== thisSubj, "overallZ2"]~datRep12[datRep12$subject== thisSubj, "overallZ"])
    abline(coef=c(theseCoeffs[1,"interceptLinear"], theseCoeffs[1,"slopeLinear"]), col="skyblue", lwd=2)
    abline(coef=c(theseCoeffs[1,"interceptMCMC"], theseCoeffs[1,"slopeMCMC"]), col="indianred", lwd=2)
    points(datRep12[datRep12$subject== thisSubj, "overallZ"], datRep12[datRep12$subject== thisSubj, "overallZ2"], pch=16, col="black", cex=1)
    box()
    text(-1.6,1.8, thisSubj)
    if (sn %in% c(1,7,13,19,25,31)){
        axis(2, at=c(-1.5, 0, 1.5))
    }

    if (sn>=29){
        axis(1, at=c(-1.5, 0, 1.5))
    }
}

title(xlab=expression(paste("Overall Sound Rating Sess. #1 (", italic("z"), " Score)")), ylab=expression(paste("Overall Sound Rating Sess. #2 (", italic("z"), " Score)")), outer=T)
dev.off()


## ##############################
## ABX with real guitars
## ###############################
datABX = read.table("../derived_datasets/ABX_dprime.csv", header=T)
datABX$typePretty = factor(datABX$type, levels=c("professional", "semi-pro", "amateur"), labels=c("Professional", "Semi-pro", "Amateur"))
datABX$cndPretty = factor(datABX$cnd, levels=c("Rosewood-Sapele",  "Rosewood-Walnut",  "Walnut-Sapele"), labels=c("Braz. Rsw. vs Sapele", "Braz. Rsw. vs Walnut",  "Sapele vs Walnut"))
dodge_size = 0.9
summABX = datABX %>% group_by(cndPretty, typePretty) %>% summarise(mean_dprime=mean(dprime), se_dprime=se(dprime))
p = ggplot(summABX, aes(cndPretty, mean_dprime, fill=typePretty))
p = p + geom_bar(stat="identity", position=position_dodge(dodge_size), colour="black")
p = p + geom_errorbar(aes(ymin=mean_dprime-se_dprime, ymax=mean_dprime+se_dprime), position=position_dodge(dodge_size), width=0.5)
p = p +  scale_fill_manual(name="", values=threeCol)
p = p + scale_y_continuous(limits=c(-0.5,3.5))
p = p + ylab(dpText) + xlab(NULL) + theme_bw2 + theme(axis.text.x = element_text(angle=45, hjust=1))
p = p + theme(legend.position = c(0.76, 0.85))
p = p + theme(legend.background = element_rect(fill=alpha("white", 0)))
p_ABX_by_type_and_guitar = p
ggsave(filename=paste0(resDir, "Fig5_ABX_by_type_and_guitar.pdf"), p, width=size1c, height=4.2)
#ggsave(filename=paste0(resDir, "Fig5.pdf"), p, width=size1c, height=4.2)


df_within_contrasts_ABX = read.table("../results/ABX/figures_data/df_within_contrasts.csv", header=T)
df_within_contrasts_ABX$labelNice = factor(df_within_contrasts_ABX$label,
    levels=c("Rosewood-Walnut-vs-Rosewood-Sapele", "Rosewood-Sapele-vs-Walnut-Sapele", "Rosewood-Walnut-vs-Walnut-Sapele"),
    labels=c("Braz. Rsw. vs Walnut \n - \n Braz. Rsw. vs Sapele", "Braz. Rsw. vs Sapele \n - \n Walnut vs Sapele", "Braz. Rsw. vs Walnut \n - \n Walnut vs Sapele"))
df_between_contrasts_ABX = read.table("../results/ABX/figures_data/df_between_contrasts.csv", header=T)

p = ggplot(df_within_contrasts_ABX, aes(labelNice, Mode)) + geom_point()
p = p + geom_hline(yintercept=0, linetype=3) + coord_flip()
p = p + geom_hline(yintercept=c(-0.2, 0.2), linetype=3, color="gray60")
##p = p + geom_point(position=position_dodge(dodgeSize))
##p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0, position=position_dodge(dodgeSize))
p = p + geom_point()
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0)
p = p + scale_y_continuous(limits=c(-1.5,1.5))
p = p + theme_bw2
p = p + ylab(dpText) + theme(axis.text.y = element_text(angle=0, hjust=0.5)) + xlab(NULL)
#ggsave(filename=paste0(resDir, "ABX_contrasts_within.pdf"), p, width=size1c, height=3)
ggsave(filename=paste0(resDir, "SI_Fig5_ABX_contrasts_within.pdf"), p, width=size1c, height=3)

p = ggplot(df_between_contrasts_ABX, aes(labelNice, Mode)) + geom_point()
p = p + geom_hline(yintercept=0, linetype=3) + coord_flip()
p = p + geom_hline(yintercept=c(-0.2, 0.2), linetype=3, color="gray60")
#p = p + geom_point(position=position_dodge(dodgeSize))
##p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0, position=position_dodge(dodgeSize))
p = p + geom_point()
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0)
p = p + scale_y_continuous(limits=c(-1.5,1.5))
p = p + theme_bw2
p = p + ylab(dpText) + xlab(NULL)
#ggsave(filename=paste0(resDir, "ABX_contrasts_between.pdf"), p, width=size1c, height=2.5)
ggsave(filename=paste0(resDir, "SI_Fig6_ABX_contrasts_between.pdf"), p, width=size1c, height=2.5)

##barplot with HDIs
df_summ_by_type_and_guitars_ABX = read.table("../results/ABX/figures_data/df_summ_by_type_and_guitars.csv", header=T)
df_summ_by_type_and_guitars_ABX$cndPretty = df_summ_by_type_and_guitars_ABX$cmp
df_summ_by_type_and_guitars_ABX$typePretty = factor(df_summ_by_type_and_guitars_ABX$type, levels=c("Professional", "Semi-pro", "Amateur"))
df_summ_by_type_and_guitars_ABX = left_join(df_summ_by_type_and_guitars_ABX, summABX)
p = ggplot(df_summ_by_type_and_guitars_ABX, aes(cndPretty, mean_dprime, fill=typePretty))
p = p + geom_bar(stat="identity", position=position_dodge(dodge_size), colour="black")
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), position=position_dodge(dodge_size), width=0.5)
p = p +  scale_fill_manual(name="", values=threeCol)
p = p + scale_y_continuous(limits=c(-0.75,3.5))
p = p + ylab(dpText) + xlab(NULL) + theme_bw2 + theme(axis.text.x = element_text(angle=45, hjust=1))
p = p + theme(legend.position = c(0.76, 0.85))
p = p + theme(legend.background = element_rect(fill=alpha("white", 0)))
ggsave(filename=paste0(resDir, "ABX_by_type_and_guitar_descr_mean_HDIs.pdf"), p, width=size1c, height=4.2)

##barplot with HDIs
p = ggplot(df_summ_by_type_and_guitars_ABX, aes(cndPretty, Mode, fill=typePretty))
p = p + geom_bar(stat="identity", position=position_dodge(dodge_size), colour="black")
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), position=position_dodge(dodge_size), width=0.5)
p = p +  scale_fill_manual(name="", values=threeCol)
p = p + scale_y_continuous(limits=c(-0.75,3.5))
p = p + ylab(dpText) + xlab(NULL) + theme_bw2 + theme(axis.text.x = element_text(angle=45, hjust=1))
p = p + theme(legend.position = c(0.76, 0.85))
p = p + theme(legend.background = element_rect(fill=alpha("white", 0)))
ggsave(filename=paste0(resDir, "ABX_by_type_and_guitar_posterior_mode_HDIs.pdf"), p, width=size1c, height=4.2)

dodge_size_ABX = -0.45
p = ggplot(df_summ_by_type_and_guitars_ABX, aes(cndPretty, Mode, shape=typePretty, color=typePretty)) + geom_point(position=position_dodge(dodge_size_ABX))
p = p + geom_hline(yintercept=0, linetype=3) + coord_flip()
p = p + geom_hline(yintercept=c(0.2), linetype=3, color="gray60")
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0, position=position_dodge(dodge_size_ABX))
p = p +  scale_color_manual(name="", values=threeCol)
p = p + scale_shape_discrete(name="")
p = p + scale_y_continuous(limits=c(-1,3))
p = p + theme_bw2
p = p + ylab(dpText) + xlab(NULL)
##p = p + theme(legend.position="top")
p = p + theme(legend.position=c(0.2, 1.067),
    legend.direction="horizontal",
    plot.margin=unit(c(1.65,0.2,0.2,0.2),"lines"))
p_ABX_posterior_by_type_guitars = p
ggsave(paste0(resDir, "Fig6_ABX_posterior_by_type_guitars.pdf"), p, width=size1c, height=3.8)
#ggsave(paste0(resDir, "Fig6.pdf"), p, width=size1c, height=3.8)

## ####################################
## ABX Synth
## ####################################

datABXSynth = read.table("../derived_datasets/ABX_synth_dprime.csv", header=T)
datABXSynthSumm = datABXSynth %>% group_by(condition, conditionLabels) %>% summarise(mean_dp=mean(dprime), se_dp=se(dprime))

datABXSynthSumm$conditionLabels = factor(datABXSynthSumm$conditionLabels, levels=c("Braz. Rsw. vs Sapele", "Braz. Rsw. vs Walnut", "Sapele vs Walnut", "Ind. Rsw. vs Sapele", "Ind. Rsw. vs Yamaha"))
p = ggplot(datABXSynthSumm, aes(x=conditionLabels, y=mean_dp))
p = p + geom_bar(stat="identity", fill=singCol)
p = p + geom_errorbar(aes(ymin=mean_dp-se_dp, ymax=mean_dp+se_dp), width=0.5)
p = p + xlab(NULL) + ylab(dpText) #+ scale_y_continuous(limits=c(0,4))
p = p + theme_bw2
p = p + theme(axis.text.x = element_text(angle=55, hjust=1))
p_barplot = p
ggsave(paste0(resDir, "Fig7_ABX_synth_barplot.pdf"), p, width=size1c, height=3.307)
#ggsave(paste0(resDir, "Fig7.pdf"), p, width=size1c, height=3.307)

datABXSynthPosterior = read.table("../results/ABX_synth/figures_data/summDF.csv", header=T)
datABXSynthPosterior$label = factor(datABXSynthPosterior$label, levels=c("Braz. Rsw. vs Sapele", "Braz. Rsw. vs Walnut", "Sapele vs Walnut", "Ind. Rsw. vs Sapele", "Ind. Rsw. vs Yamaha"))
p = ggplot(datABXSynthPosterior, aes(label, Mode)) + geom_point()
p = p + geom_hline(yintercept=0, linetype=3) + coord_flip()
p = p + geom_hline(yintercept=c(0.2), linetype=3, color="gray60")
p = p + geom_point()
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0)
p = p + scale_y_continuous(limits=c(0,4))
p = p + theme_bw2
p = p + ylab(dpText) + xlab(NULL)
ggsave(paste0(resDir, "Fig8_ABX_synth_posterior.pdf"), p, width=size1c, height=3.307)
#ggsave(paste0(resDir, "Fig8.pdf"), p, width=size1c, height=3.307)

p = ggplot(datABXSynthPosterior, aes(x=label, y=Mode))
p = p + geom_bar(stat="identity", fill=singCol)
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0.5)
p = p + xlab(NULL) + ylab(dpText) #+ scale_y_continuous(limits=c(0,4))
p = p + theme_bw2
p = p + theme(axis.text.x = element_text(angle=55, hjust=1))
ggsave(paste0(resDir, "ABX_synth_barplot_posterior_mode_HDIs.pdf"), p, width=size1c, height=3.307)

datABXSynthPosterior$conditionLabels = datABXSynthPosterior$label
datABXSynthPosterior = left_join(datABXSynthPosterior, datABXSynthSumm)

p = ggplot(datABXSynthPosterior, aes(x=label, y=mean_dp))
p = p + geom_bar(stat="identity", fill=singCol)
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0.5)
p = p + xlab(NULL) + ylab(dpText) #+ scale_y_continuous(limits=c(0,4))
p = p + theme_bw2
p = p + theme(axis.text.x = element_text(angle=55, hjust=1))
ggsave(paste0(resDir, "ABX_synth_barplot_descr_mean_HDIs.pdf"), p, width=size1c, height=3.307)

## ABX Synth CIs
datABXSynthCIs = read.table("../derived_datasets/ABX_synth_dprime_CIs.csv", header=T)
datABXSynthCIs$conditionLabels = factor(datABXSynthCIs$conditionLabels, levels=c("Braz. Rsw. vs Sapele", "Braz. Rsw. vs Walnut", "Sapele vs Walnut", "Ind. Rsw. vs Sapele", "Ind. Rsw. vs Yamaha"))
datABXSynthCIs$listener = factor(datABXSynthCIs$listener, levels=mixedsort(levels(datABXSynthCIs$listener)))

dg = 0.5
p = ggplot(datABXSynthCIs, aes(conditionLabels, dprime, color=listener))
p = p + geom_hline(yintercept=0, color="gray")
p = p + geom_point(position=position_dodge(dg))
p = p + geom_errorbar(aes(ymin=dprime-se, ymax=dprime+se), width=0.5, position=position_dodge(dg))
p = p + ylab(dpText) + xlab(NULL)
p = p + theme_bw2
p = p + theme(axis.text.x = element_text(angle=55, hjust=1))
p = p + scale_color_manual(name="Listener", values=clsAllListenersSynth)
#ggsave(paste0(resDir, "ABX_synth_ind_lis_se.pdf"), p, width=size1.5c, height=5)
ggsave(paste0(resDir, "SI_Fig7_ABX_synth_ind_lis_se.pdf"), p, width=size1.5c, height=5)

## ####################################
## Overall & Playability Unblinded HDIs
## ####################################
datSummOverallUnblinded = read.table("../results/unblinded_overall/figures_data/df_within_contrasts.csv", header=T)
datSummOverallUnblinded$scale = "Overall"
datSummPlayabilityUnblinded = read.table("../results/unblinded_playability/figures_data/df_within_contrasts.csv", header=T)
datSummPlayabilityUnblinded$scale = "Playability"

datSummOverallPlayabilityUnblinded = rbind(datSummOverallUnblinded, datSummPlayabilityUnblinded)

dodgeSize = -0.75
p = ggplot(datSummOverallPlayabilityUnblinded, aes(x=labelNice, y=Mode, shape=scale, color=scale))
p = p + geom_hline(yintercept=0, linetype=3) + coord_flip()
p = p + geom_hline(yintercept=c(-0.2, 0.2), linetype=3, color="gray60")
p = p + geom_point(position=position_dodge(dodgeSize))
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0, position=position_dodge(dodgeSize))
p = p + scale_y_continuous(limits=c(-1,1))
p = p + scale_shape_discrete(name=NULL)
p = p + scale_color_manual(name=NULL, values=twoCol)
p = p + theme_bw2 + theme(legend.position=c(0.4, 1.065),
    legend.direction="horizontal",
    plot.margin=unit(c(1.65,0.2,0.2,0.2),"lines"))
p = p + ylab("Rating Difference") + theme(axis.title.x = element_text(hjust=0.5)) + xlab(NULL)
p_HDIs_contrasts_within_unblinded = p
#ggsave(filename=paste0(resDir, "HDIs_contrasts_within_unblinded.pdf"), p_HDIs_contrasts_within_unblinded, width=size1c, height=3.8)
ggsave(filename=paste0(resDir, "SI_Fig8_overall_playability_unblinded_CIs.pdf"), p_HDIs_contrasts_within_unblinded, width=size1c, height=3.8)

## #############################################
## Overall playability barplot vertical
## #############################################
datRatingsUnblinded = read.table("../datasets/unblinded_ratings.csv", header=T)
datRatingsSubjSummOverallUnblinded = datRatingsUnblinded %>% group_by(subject, guitar) %>% summarize(s_mean=mean(overall))
datRatingsSubjSummPlayabilityUnblinded = datRatingsUnblinded %>% group_by(subject, guitar) %>% summarize(s_mean=mean(playability))
datRatingsSummOverallUnblinded = datRatingsSubjSummOverallUnblinded %>% group_by(guitar) %>% summarize(mean=mean(s_mean), se=se(s_mean))
datRatingsSummOverallUnblinded$scale = "Overall"
datRatingsSummPlayabilityUnblinded = datRatingsSubjSummPlayabilityUnblinded %>% group_by(guitar) %>% summarize(mean=mean(s_mean), se=se(s_mean))
datRatingsSummPlayabilityUnblinded$scale = "Playability"

datRatingsSummOverallPlayabilityUnblinded = rbind(datRatingsSummOverallUnblinded, datRatingsSummPlayabilityUnblinded)
datRatingsSummOverallPlayabilityUnblinded$guitarLabel = gsub2(guitarCodes, guitarLabelsShort, datRatingsSummOverallPlayabilityUnblinded$guitar)


dodgeSize = 0.9
p = ggplot(datRatingsSummOverallPlayabilityUnblinded, aes(x=guitarLabel, y=mean, fill=scale))
p = p + geom_bar(stat="identity", position=position_dodge(dodgeSize))
p = p + geom_errorbar(aes(ymin=mean-se, ymax=mean+se), position=position_dodge(dodgeSize), width=0.5)
p = p + scale_fill_manual(name=NULL, values=twoCol)
p = p + theme_bw2 + theme(axis.text.x = element_text(angle=45,hjust=1))
p = p + theme(legend.position="top")
p = p + ylab("Rating") + xlab(NULL)
p_barplot_overall_playability_unblinded_v = p
ggsave(filename=paste0(resDir, "barplot_overall_playability_unblinded_vertical.pdf"), p_barplot_overall_playability_unblinded_v, width=size1c, height=size1c)


## ##############################
## Factor Scores Unblinded
## ##############################

datFAScoresUnblinded = read.table("../derived_datasets/unblinded_ratings_with_EFA_scores.csv", header=T)
datFAScoresUnblindedStacked = data.frame(datFAScoresUnblinded[1:5], stack(datFAScoresUnblinded, select=c("F1", "F2", "F3")))
datFAScoresUnblindedSummSubj = datFAScoresUnblindedStacked %>% group_by(subject, guitar, ind) %>% summarize(meanSubjScore=mean(values))
datFAScoresUnblindedSumm = datFAScoresUnblindedSummSubj %>% group_by(guitar, ind) %>% summarize(meanScore=mean(meanSubjScore), seScore=se(meanSubjScore))
datFAScoresUnblindedSumm$guitarLabel = gsub2(guitarCodes, guitarLabelsShort, datFAScoresUnblindedSumm$guitar)


dodgeSize = 0.9
p = ggplot(datFAScoresUnblindedSumm, aes(x=guitarLabel, y=meanScore, fill=ind))
p = p + geom_bar(stat="identity", position=position_dodge(dodgeSize))
p = p + geom_errorbar(aes(ymin=meanScore-seScore, ymax=meanScore+seScore), position=position_dodge(dodgeSize), width=0.5)
p = p + scale_fill_manual(name=NULL, values=factorsCol)
p = p + theme_bw2 + theme(axis.text.x = element_text(angle=45,hjust=1))
p = p + theme(legend.position="top")
p = p + scale_y_continuous(limits=c(-1,1))
p = p + ylab("Factor Score") + xlab(NULL)
p_barplot_factor_scores_v = p
ggsave(filename=paste0(resDir, "barplot_factor_scores_unblinded_vertical.pdf"), p_barplot_factor_scores_v, width=size1c, height=3.8)



postDatUnblindedF1 = read.table("../results/unblinded_factor_scores_F1/figures_data/df_within_contrasts.csv", header=T)
postDatUnblindedF1$factor = "F1"

postDatUnblindedF2 = read.table("../results/unblinded_factor_scores_F2/figures_data/df_within_contrasts.csv", header=T)
postDatUnblindedF2$factor = "F2"

postDatUnblindedF3 = read.table("../results/unblinded_factor_scores_F3/figures_data/df_within_contrasts.csv", header=T)
postDatUnblindedF3$factor = "F3"
postDatFAScoresUnblinded = rbind(postDatUnblindedF1, postDatUnblindedF2, postDatUnblindedF3)


dodgeSize = -0.75
p = ggplot(postDatFAScoresUnblinded, aes(x=labelNice, y=Mode, shape=factor, color=factor))
p = p + geom_hline(yintercept=0, linetype=3) + coord_flip()
p = p + geom_hline(yintercept=c(-0.2, 0.2), linetype=3, color="gray60")
p = p + geom_point(position=position_dodge(dodgeSize))
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0, position=position_dodge(dodgeSize))
p = p + scale_y_continuous(limits=c(-1,1))
p = p + scale_shape_discrete(name=NULL)
p = p + scale_color_manual(name=NULL, values=factorsCol)
p = p + theme_bw2 + theme(legend.position=c(0.4, 1.065),
    legend.direction="horizontal",
    plot.margin=unit(c(1.65,0.2,0.2,0.2),"lines"))
p = p + ylab("Factor Score Difference") + theme(axis.title.x = element_text(hjust=0.5)) + xlab(NULL)
p_HDIs_contrasts_within_factor_scores_unblinded = p
#ggsave(filename=paste0(resDir, "HDIs_contrasts_within_factor_scores_unblinded.pdf"), p_HDIs_contrasts_within_factor_scores, width=size1c, height=3.8)
ggsave(filename=paste0(resDir, "SI_Fig9_factor_scores_unblinded_CIs.pdf"), p_HDIs_contrasts_within_factor_scores_unblinded, width=size1c, height=3.8)



## #######################
## Visual HDIs
## #######################

datRatingsSummOverallVisual = read.table("../results/visual_overall/figures_data/df_within_contrasts.csv", header=T)
p = ggplot(datRatingsSummOverallVisual, aes(x=labelNice, y=Mode))
p = p + geom_hline(yintercept=0, linetype=3) + coord_flip()
p = p + geom_hline(yintercept=c(-0.2, 0.2), linetype=3, color="gray60")
p = p + geom_point(position=position_dodge(dodgeSize))
p = p + geom_errorbar(aes(ymin=HDIlow, ymax=HDIhigh), width=0, position=position_dodge(dodgeSize))
p = p + scale_y_continuous(limits=c(-1.5,1.5))
p = p + ylab("Rating Difference") + theme(axis.title.x = element_text(hjust=0.5)) + xlab(NULL)
p_HDIs_contrasts_within_visual = p
#ggsave(filename=paste0(resDir, "HDIs_contrasts_within_visual.pdf"), p_HDIs_contrasts_within_visual, width=size1c, height=3.8)
ggsave(filename=paste0(resDir, "SI_Fig10_overall_visual_CIs.pdf"), p_HDIs_contrasts_within_visual, width=size1c, height=3.8)

datRatingsVisual = read.table("../datasets/visual_ratings.csv", header=T)
datRatingsSummOverallVisual = datRatingsVisual %>% group_by(guitar) %>% summarize(mean=mean(overall), se=se(overall))
datRatingsSummOverallVisual$guitarLabel = gsub2(guitarCodes, guitarLabelsShort, datRatingsSummOverallVisual$guitar)

dodgeSize = 0.9
p = ggplot(datRatingsSummOverallVisual, aes(x=guitarLabel, y=mean))
p = p + geom_bar(stat="identity", position=position_dodge(dodgeSize))
p = p + geom_errorbar(aes(ymin=mean-se, ymax=mean+se), position=position_dodge(dodgeSize), width=0.5)
p = p + scale_fill_manual(name=NULL, values=singCol)
p = p + theme_bw2 + theme(axis.text.x = element_text(angle=45,hjust=1))
p = p + theme(legend.position="top")
p = p + ylab("Rating") + xlab(NULL)
p_barplot_overall_playability_visual_v = p
ggsave(filename=paste0(resDir, "barplot_overall_visual_vertical.pdf"), p_barplot_overall_playability_visual_v, width=size1c, height=size1c)


