library(psyphy)
library(colorspace)

add.alpha = function(col, alpha=1){
  if(missing(col))
      stop("Please provide a vector of colours.")
  apply(sapply(col, col2rgb)/255, 2, 
        function(x) 
            rgb(x[1], x[2], x[3], alpha=alpha))  
} 

capitalizeString = function(x) {
   substr(x, 1, 1) = toupper(substr(x, 1, 1))
   return(x)
}


## function to compute d' with the loglinear correction
dp_ABX_log_lin = function(nCorrA, nA, nIncorrB, nB, method="diff"){
    HA = (nCorrA + 0.5) / (nA+1)
    FA = (nIncorrB + 0.5) / (nB+1)
    if (HA >= FA){
        thisDPLogLin = dprime.ABX(HA, FA, method=method)
    } else {
        thisDPLogLin = -dprime.ABX(FA, HA, method=method)
    }
    return (thisDPLogLin)
}

## function to compute d' with the 1/2N correction
dp_ABX_2N = function(nCorrA, nA, nIncorrB, nB, method="diff"){
    if (nCorrA == nA){
        HA = 1 - 1/(2*nA)
    } else if (nCorrA == 0){
        HA = 1/(2*nA)
    } else {
        HA = nCorrA / nA
    }
    
    if (nIncorrB == nB){
        FA = 1 - 1/(2*nB)
    } else if (nIncorrB == 0){
        FA = 1/(2*nB)
    } else{
        FA = nIncorrB / nB
    }

    if (HA >= FA){
        thisDP2N = dprime.ABX(HA, FA, method=method)
    } else {
        thisDP2N = -dprime.ABX(FA, HA, method=method)
    }

    return (dpRev=thisDP2N)
}

findLevNum = function(levName, fctr){
    xn = as.numeric(as.factor(fctr))
    levNum = xn[which(fctr==levName)[1]]
    return(levNum)
}

findLevLab = function(levNum, fctr){
    xn = as.numeric(as.factor(fctr))
    levLab = as.character(fctr[which(xn==levNum)[1]])
    return(levLab)
}

getCenTend = function(sampleVec, cenTend=c("mode", "median", "mean")[1]){
    if (cenTend == "mean"){
        ct = mean(sampleVec)
    } else if (cenTend == "median"){
        ct = median(sampleVec)
    }  else if (cenTend == "mode"){
        mcmcDensity = density(sampleVec)
        ct = mcmcDensity$x[which.max(mcmcDensity$y)]
    }
    
    return(ct)
}


gsub2 = function(pattern, replacement, x, ...) {
    for(i in 1:length(pattern))
        x <- gsub(pattern[i], replacement[i], x, ...)
    x
}

pastelize = function(col, weight=2.4){
    col = col2rgb(col)/255
    maxc = max(col)
    if (maxc < 1.0 && maxc > 0){
        ## scale colour
        scale = 1.0 / maxc
        col = col * scale
    }
    # now decrease saturation
    total = sum(col)
    slack = 0
    for (x in col){
        slack = slack + (1.0 - x)
    }

    # want to increase weight from total to weight
    # pick x s.t.  slack * x == weight - total
    # x = (weight - total) / slack
    x = (weight - total) / slack
    for (i in 1:length(col)){
        col[i] = col[i] + (x * (1.0 - col[i]))
    }
    col = rgb(col[1], col[2], col[3])
    return (col)
}


## compute standard error of the mean
se = function(x, na.rm=FALSE){
    if (na.rm == TRUE){
        x = x[is.na(x)==FALSE]
    }
    n <- length(x)
    out <- sd(x) / sqrt(n)
    return(out)
}

changeShade = function(cols, val){
    ## adapted from https://stackoverflow.com/questions/30219738/is-there-a-way-to-programmatically-darken-the-color-given-rgb-values
    ## darken:
    ## changeShade("#0072B2", 1/2)
    ## lighten:
    ## changeShade("#0072B2", 2)
    cols <- readhex(file = textConnection(paste(cols, collapse = "\n")),
                    class = "RGB")
    ##transform to hue/lightness/saturation colorspace
    cols1 = as(cols, "HLS")
    cols1@coords[, "L"] = cols1@coords[, "L"] * val
    ##going via rgb seems to work better  
    cols1 <- as(cols1, "RGB")
    cols1 <- hex(cols1)
    return(cols1)
}
