library(ggplot2)
library(cowplot)
currDir = getwd()
setwd("../")
source("global_parameters.R")
setwd(currDir)
source("../utils.R")

##directory where to save the results
resDir = "../../results/wood_properties/"
dir.create(resDir, recursive=T, showWarnings=F)

ap = 1
cls = c(adjustcolor( "black", alpha.f = ap), adjustcolor( "red", alpha.f = ap))
dat = read.table("../../datasets/wood_data.csv", header=T, sep=" ")
dat$set = factor(dat$set)
dat$half = factor(dat$half)
dat$woodPretty = factor(dat$wood, levels=c("braz", "indi", "maho", "mapl", "sape", "waln"), labels=c("Braz. Rsw.", "Ind. Rsw.", "Mahogany", "Maple", "Sapele", "Walnut"))


p = ggplot(dat, aes(woodPretty, density, color=set)) + geom_point(shape=8)
p = p + scale_color_manual(name=NULL, values=cls, guide=FALSE)
p = p + ylab(expression(paste("Density (", kg/m^3, ")")))
p = p + theme_bw2
p = p + theme(axis.title.x=element_blank(),
              axis.text.x=element_blank())
p1 = p

datStiff = dat
datStiff$D1_Gpa = NULL
datStiff$D3_Gpa = NULL
datStiff$D4_Gpa = NULL
datStiff$density = NULL
datStiff = rbind(datStiff, datStiff, datStiff)
datStiff$stiff = c(dat$D1_Gpa, dat$D3_Gpa, dat$D4_Gpa)
datStiff$dtype = rep(c("D1", "D3", "D4"), each=dim(dat)[1])

p = ggplot(datStiff, aes(woodPretty, stiff, color=set, shape=dtype)) + geom_point()
p = p + scale_shape_manual(name=NULL, values=c(8,1,3), guide=FALSE)
p = p + scale_color_manual(name=NULL, values=cls, guide=FALSE)
p = p + scale_y_continuous(trans="log10", breaks=c(0.1, 1))
p = p + annotation_logticks(sides="l")
p = p + theme_bw2
p = p + xlab(NULL) + ylab(expression(paste(italic(D), " value (GPa)")))
p = p + theme(axis.text.x = element_text(angle=45, hjust=1, vjust=1))
p = p + theme(plot.margin = unit(c(0,0,0,0.7), "cm")) 
p2 = p

rh = 0.45
pg = plot_grid(p1, p2, labels=c("A", "B"), nrow=2, rel_heights=c(rh, 1-rh), align="v", hjust=-0.5)
save_plot(paste0(resDir, "woodplot_combined.pdf"), pg, base_width=size1c+0.5, base_height=4.25)

